@@ -14,6 +14,7 @@ def _get_kwargs(
     *,
     max_keys: int,
     marker: Union[Unset, None, str] = UNSET,
+    prefix: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     pass
 
@@ -22,6 +23,8 @@ def _get_kwargs(
 
     params["marker"] = marker
 
+    params["prefix"] = prefix
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     return {
@@ -63,6 +66,7 @@ def sync_detailed(
     client: Union[AuthenticatedClient, Client],
     max_keys: int,
     marker: Union[Unset, None, str] = UNSET,
+    prefix: Union[Unset, None, str] = UNSET,
 ) -> Response[ListStoredFilesResponse200]:
     """List the file keys available in the workspace files storage (S3)
 
@@ -70,6 +74,7 @@ def sync_detailed(
         workspace (str):
         max_keys (int):
         marker (Union[Unset, None, str]):
+        prefix (Union[Unset, None, str]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -83,6 +88,7 @@ def sync_detailed(
         workspace=workspace,
         max_keys=max_keys,
         marker=marker,
+        prefix=prefix,
     )
 
     response = client.get_httpx_client().request(
@@ -98,6 +104,7 @@ def sync(
     client: Union[AuthenticatedClient, Client],
     max_keys: int,
     marker: Union[Unset, None, str] = UNSET,
+    prefix: Union[Unset, None, str] = UNSET,
 ) -> Optional[ListStoredFilesResponse200]:
     """List the file keys available in the workspace files storage (S3)
 
@@ -105,6 +112,7 @@ def sync(
         workspace (str):
         max_keys (int):
         marker (Union[Unset, None, str]):
+        prefix (Union[Unset, None, str]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -119,6 +127,7 @@ def sync(
         client=client,
         max_keys=max_keys,
         marker=marker,
+        prefix=prefix,
     ).parsed
 
 
@@ -128,6 +137,7 @@ async def asyncio_detailed(
     client: Union[AuthenticatedClient, Client],
     max_keys: int,
     marker: Union[Unset, None, str] = UNSET,
+    prefix: Union[Unset, None, str] = UNSET,
 ) -> Response[ListStoredFilesResponse200]:
     """List the file keys available in the workspace files storage (S3)
 
@@ -135,6 +145,7 @@ async def asyncio_detailed(
         workspace (str):
         max_keys (int):
         marker (Union[Unset, None, str]):
+        prefix (Union[Unset, None, str]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -148,6 +159,7 @@ async def asyncio_detailed(
         workspace=workspace,
         max_keys=max_keys,
         marker=marker,
+        prefix=prefix,
     )
 
     response = await client.get_async_httpx_client().request(**kwargs)
@@ -161,6 +173,7 @@ async def asyncio(
     client: Union[AuthenticatedClient, Client],
     max_keys: int,
     marker: Union[Unset, None, str] = UNSET,
+    prefix: Union[Unset, None, str] = UNSET,
 ) -> Optional[ListStoredFilesResponse200]:
     """List the file keys available in the workspace files storage (S3)
 
@@ -168,6 +181,7 @@ async def asyncio(
         workspace (str):
         max_keys (int):
         marker (Union[Unset, None, str]):
+        prefix (Union[Unset, None, str]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -183,5 +197,6 @@ async def asyncio(
             client=client,
             max_keys=max_keys,
             marker=marker,
+            prefix=prefix,
         )
     ).parsed
