@@ -1,8 +1,10 @@
-from typing import Any, Dict, Union
+from http import HTTPStatus
+from typing import Any, Dict, Optional, Union
 
 import httpx
 
-from ...client import Client
+from ... import errors
+from ...client import AuthenticatedClient, Client
 from ...types import UNSET, Response, Unset
 
 
@@ -12,15 +14,9 @@ def _get_kwargs(
     resume_id: int,
     signature: str,
     *,
-    client: Client,
     approver: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
-    url = "{}/w/{workspace}/jobs_u/cancel/{id}/{resume_id}/{signature}".format(
-        client.base_url, workspace=workspace, id=id, resume_id=resume_id, signature=signature
-    )
-
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
+    pass
 
     params: Dict[str, Any] = {}
     params["approver"] = approver
@@ -29,20 +25,29 @@ def _get_kwargs(
 
     return {
         "method": "get",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
+        "url": "/w/{workspace}/jobs_u/cancel/{id}/{resume_id}/{signature}".format(
+            workspace=workspace,
+            id=id,
+            resume_id=resume_id,
+            signature=signature,
+        ),
         "params": params,
     }
 
 
-def _build_response(*, response: httpx.Response) -> Response[Any]:
+def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[Any]:
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(response.status_code, response.content)
+    else:
+        return None
+
+
+def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[Any]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=None,
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -52,7 +57,7 @@ def sync_detailed(
     resume_id: int,
     signature: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     approver: Union[Unset, None, str] = UNSET,
 ) -> Response[Any]:
     """cancel a job for a suspended flow
@@ -64,6 +69,10 @@ def sync_detailed(
         signature (str):
         approver (Union[Unset, None, str]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[Any]
     """
@@ -73,16 +82,14 @@ def sync_detailed(
         id=id,
         resume_id=resume_id,
         signature=signature,
-        client=client,
         approver=approver,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio_detailed(
@@ -91,7 +98,7 @@ async def asyncio_detailed(
     resume_id: int,
     signature: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
     approver: Union[Unset, None, str] = UNSET,
 ) -> Response[Any]:
     """cancel a job for a suspended flow
@@ -103,6 +110,10 @@ async def asyncio_detailed(
         signature (str):
         approver (Union[Unset, None, str]):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[Any]
     """
@@ -112,11 +123,9 @@ async def asyncio_detailed(
         id=id,
         resume_id=resume_id,
         signature=signature,
-        client=client,
         approver=approver,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
