@@ -15,6 +15,7 @@ def _get_kwargs(
     *,
     order_desc: Union[Unset, None, bool] = UNSET,
     created_by: Union[Unset, None, str] = UNSET,
+    label: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
@@ -27,9 +28,12 @@ def _get_kwargs(
     args: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     has_null_parent: Union[Unset, None, bool] = UNSET,
+    is_not_schedule: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
     pass
 
@@ -38,6 +42,8 @@ def _get_kwargs(
 
     params["created_by"] = created_by
 
+    params["label"] = label
+
     params["parent_job"] = parent_job
 
     params["script_path_exact"] = script_path_exact
@@ -70,12 +76,18 @@ def _get_kwargs(
 
     params["tag"] = tag
 
+    params["page"] = page
+
+    params["per_page"] = per_page
+
     params["is_skipped"] = is_skipped
 
     params["is_flow_step"] = is_flow_step
 
     params["has_null_parent"] = has_null_parent
 
+    params["is_not_schedule"] = is_not_schedule
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     return {
@@ -122,6 +134,7 @@ def sync_detailed(
     client: Union[AuthenticatedClient, Client],
     order_desc: Union[Unset, None, bool] = UNSET,
     created_by: Union[Unset, None, str] = UNSET,
+    label: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
@@ -134,9 +147,12 @@ def sync_detailed(
     args: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     has_null_parent: Union[Unset, None, bool] = UNSET,
+    is_not_schedule: Union[Unset, None, bool] = UNSET,
 ) -> Response[List["ListCompletedJobsResponse200Item"]]:
     """list all completed jobs
 
@@ -144,6 +160,7 @@ def sync_detailed(
         workspace (str):
         order_desc (Union[Unset, None, bool]):
         created_by (Union[Unset, None, str]):
+        label (Union[Unset, None, str]):
         parent_job (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
@@ -156,9 +173,12 @@ def sync_detailed(
         args (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
+        page (Union[Unset, None, int]):
+        per_page (Union[Unset, None, int]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
         has_null_parent (Union[Unset, None, bool]):
+        is_not_schedule (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -172,6 +192,7 @@ def sync_detailed(
         workspace=workspace,
         order_desc=order_desc,
         created_by=created_by,
+        label=label,
         parent_job=parent_job,
         script_path_exact=script_path_exact,
         script_path_start=script_path_start,
@@ -184,9 +205,12 @@ def sync_detailed(
         args=args,
         result=result,
         tag=tag,
+        page=page,
+        per_page=per_page,
         is_skipped=is_skipped,
         is_flow_step=is_flow_step,
         has_null_parent=has_null_parent,
+        is_not_schedule=is_not_schedule,
     )
 
     response = client.get_httpx_client().request(
@@ -202,6 +226,7 @@ def sync(
     client: Union[AuthenticatedClient, Client],
     order_desc: Union[Unset, None, bool] = UNSET,
     created_by: Union[Unset, None, str] = UNSET,
+    label: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
@@ -214,9 +239,12 @@ def sync(
     args: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     has_null_parent: Union[Unset, None, bool] = UNSET,
+    is_not_schedule: Union[Unset, None, bool] = UNSET,
 ) -> Optional[List["ListCompletedJobsResponse200Item"]]:
     """list all completed jobs
 
@@ -224,6 +252,7 @@ def sync(
         workspace (str):
         order_desc (Union[Unset, None, bool]):
         created_by (Union[Unset, None, str]):
+        label (Union[Unset, None, str]):
         parent_job (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
@@ -236,9 +265,12 @@ def sync(
         args (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
+        page (Union[Unset, None, int]):
+        per_page (Union[Unset, None, int]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
         has_null_parent (Union[Unset, None, bool]):
+        is_not_schedule (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -253,6 +285,7 @@ def sync(
         client=client,
         order_desc=order_desc,
         created_by=created_by,
+        label=label,
         parent_job=parent_job,
         script_path_exact=script_path_exact,
         script_path_start=script_path_start,
@@ -265,9 +298,12 @@ def sync(
         args=args,
         result=result,
         tag=tag,
+        page=page,
+        per_page=per_page,
         is_skipped=is_skipped,
         is_flow_step=is_flow_step,
         has_null_parent=has_null_parent,
+        is_not_schedule=is_not_schedule,
     ).parsed
 
 
@@ -277,6 +313,7 @@ async def asyncio_detailed(
     client: Union[AuthenticatedClient, Client],
     order_desc: Union[Unset, None, bool] = UNSET,
     created_by: Union[Unset, None, str] = UNSET,
+    label: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
@@ -289,9 +326,12 @@ async def asyncio_detailed(
     args: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     has_null_parent: Union[Unset, None, bool] = UNSET,
+    is_not_schedule: Union[Unset, None, bool] = UNSET,
 ) -> Response[List["ListCompletedJobsResponse200Item"]]:
     """list all completed jobs
 
@@ -299,6 +339,7 @@ async def asyncio_detailed(
         workspace (str):
         order_desc (Union[Unset, None, bool]):
         created_by (Union[Unset, None, str]):
+        label (Union[Unset, None, str]):
         parent_job (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
@@ -311,9 +352,12 @@ async def asyncio_detailed(
         args (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
+        page (Union[Unset, None, int]):
+        per_page (Union[Unset, None, int]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
         has_null_parent (Union[Unset, None, bool]):
+        is_not_schedule (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -327,6 +371,7 @@ async def asyncio_detailed(
         workspace=workspace,
         order_desc=order_desc,
         created_by=created_by,
+        label=label,
         parent_job=parent_job,
         script_path_exact=script_path_exact,
         script_path_start=script_path_start,
@@ -339,9 +384,12 @@ async def asyncio_detailed(
         args=args,
         result=result,
         tag=tag,
+        page=page,
+        per_page=per_page,
         is_skipped=is_skipped,
         is_flow_step=is_flow_step,
         has_null_parent=has_null_parent,
+        is_not_schedule=is_not_schedule,
     )
 
     response = await client.get_async_httpx_client().request(**kwargs)
@@ -355,6 +403,7 @@ async def asyncio(
     client: Union[AuthenticatedClient, Client],
     order_desc: Union[Unset, None, bool] = UNSET,
     created_by: Union[Unset, None, str] = UNSET,
+    label: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
@@ -367,9 +416,12 @@ async def asyncio(
     args: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     has_null_parent: Union[Unset, None, bool] = UNSET,
+    is_not_schedule: Union[Unset, None, bool] = UNSET,
 ) -> Optional[List["ListCompletedJobsResponse200Item"]]:
     """list all completed jobs
 
@@ -377,6 +429,7 @@ async def asyncio(
         workspace (str):
         order_desc (Union[Unset, None, bool]):
         created_by (Union[Unset, None, str]):
+        label (Union[Unset, None, str]):
         parent_job (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
@@ -389,9 +442,12 @@ async def asyncio(
         args (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
+        page (Union[Unset, None, int]):
+        per_page (Union[Unset, None, int]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
         has_null_parent (Union[Unset, None, bool]):
+        is_not_schedule (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -407,6 +463,7 @@ async def asyncio(
             client=client,
             order_desc=order_desc,
             created_by=created_by,
+            label=label,
             parent_job=parent_job,
             script_path_exact=script_path_exact,
             script_path_start=script_path_start,
@@ -419,8 +476,11 @@ async def asyncio(
             args=args,
             result=result,
             tag=tag,
+            page=page,
+            per_page=per_page,
             is_skipped=is_skipped,
             is_flow_step=is_flow_step,
             has_null_parent=has_null_parent,
+            is_not_schedule=is_not_schedule,
         )
     ).parsed
