@@ -6,7 +6,8 @@ import httpx
 
 from ... import errors
 from ...client import AuthenticatedClient, Client
-from ...models.list_jobs_response_200_item import ListJobsResponse200Item
+from ...models.list_jobs_response_200_item_type_0 import ListJobsResponse200ItemType0
+from ...models.list_jobs_response_200_item_type_1 import ListJobsResponse200ItemType1
 from ...types import UNSET, Response, Unset
 
 
@@ -14,6 +15,7 @@ def _get_kwargs(
     workspace: str,
     *,
     created_by: Union[Unset, None, str] = UNSET,
+    label: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
@@ -29,17 +31,22 @@ def _get_kwargs(
     args: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     has_null_parent: Union[Unset, None, bool] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
     all_workspaces: Union[Unset, None, bool] = UNSET,
+    is_not_schedule: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
     pass
 
     params: Dict[str, Any] = {}
     params["created_by"] = created_by
 
+    params["label"] = label
+
     params["parent_job"] = parent_job
 
     params["script_path_exact"] = script_path_exact
@@ -86,6 +93,10 @@ def _get_kwargs(
 
     params["result"] = result
 
+    params["page"] = page
+
+    params["per_page"] = per_page
+
     params["is_skipped"] = is_skipped
 
     params["is_flow_step"] = is_flow_step
@@ -96,6 +107,8 @@ def _get_kwargs(
 
     params["all_workspaces"] = all_workspaces
 
+    params["is_not_schedule"] = is_not_schedule
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     return {
@@ -109,12 +122,30 @@ def _get_kwargs(
 
 def _parse_response(
     *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[List["ListJobsResponse200Item"]]:
+) -> Optional[List[Union["ListJobsResponse200ItemType0", "ListJobsResponse200ItemType1"]]]:
     if response.status_code == HTTPStatus.OK:
         response_200 = []
         _response_200 = response.json()
         for response_200_item_data in _response_200:
-            response_200_item = ListJobsResponse200Item.from_dict(response_200_item_data)
+
+            def _parse_response_200_item(
+                data: object,
+            ) -> Union["ListJobsResponse200ItemType0", "ListJobsResponse200ItemType1"]:
+                try:
+                    if not isinstance(data, dict):
+                        raise TypeError()
+                    response_200_item_type_0 = ListJobsResponse200ItemType0.from_dict(data)
+
+                    return response_200_item_type_0
+                except:  # noqa: E722
+                    pass
+                if not isinstance(data, dict):
+                    raise TypeError()
+                response_200_item_type_1 = ListJobsResponse200ItemType1.from_dict(data)
+
+                return response_200_item_type_1
+
+            response_200_item = _parse_response_200_item(response_200_item_data)
 
             response_200.append(response_200_item)
 
@@ -127,7 +158,7 @@ def _parse_response(
 
 def _build_response(
     *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Response[List["ListJobsResponse200Item"]]:
+) -> Response[List[Union["ListJobsResponse200ItemType0", "ListJobsResponse200ItemType1"]]]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -141,6 +172,7 @@ def sync_detailed(
     *,
     client: Union[AuthenticatedClient, Client],
     created_by: Union[Unset, None, str] = UNSET,
+    label: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
@@ -156,17 +188,21 @@ def sync_detailed(
     args: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     has_null_parent: Union[Unset, None, bool] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
     all_workspaces: Union[Unset, None, bool] = UNSET,
-) -> Response[List["ListJobsResponse200Item"]]:
+    is_not_schedule: Union[Unset, None, bool] = UNSET,
+) -> Response[List[Union["ListJobsResponse200ItemType0", "ListJobsResponse200ItemType1"]]]:
     """list all jobs
 
     Args:
         workspace (str):
         created_by (Union[Unset, None, str]):
+        label (Union[Unset, None, str]):
         parent_job (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
@@ -182,23 +218,27 @@ def sync_detailed(
         args (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
+        page (Union[Unset, None, int]):
+        per_page (Union[Unset, None, int]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
         has_null_parent (Union[Unset, None, bool]):
         success (Union[Unset, None, bool]):
         all_workspaces (Union[Unset, None, bool]):
+        is_not_schedule (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[List['ListJobsResponse200Item']]
+        Response[List[Union['ListJobsResponse200ItemType0', 'ListJobsResponse200ItemType1']]]
     """
 
     kwargs = _get_kwargs(
         workspace=workspace,
         created_by=created_by,
+        label=label,
         parent_job=parent_job,
         script_path_exact=script_path_exact,
         script_path_start=script_path_start,
@@ -214,11 +254,14 @@ def sync_detailed(
         args=args,
         tag=tag,
         result=result,
+        page=page,
+        per_page=per_page,
         is_skipped=is_skipped,
         is_flow_step=is_flow_step,
         has_null_parent=has_null_parent,
         success=success,
         all_workspaces=all_workspaces,
+        is_not_schedule=is_not_schedule,
     )
 
     response = client.get_httpx_client().request(
@@ -233,6 +276,7 @@ def sync(
     *,
     client: Union[AuthenticatedClient, Client],
     created_by: Union[Unset, None, str] = UNSET,
+    label: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
@@ -248,17 +292,21 @@ def sync(
     args: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     has_null_parent: Union[Unset, None, bool] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
     all_workspaces: Union[Unset, None, bool] = UNSET,
-) -> Optional[List["ListJobsResponse200Item"]]:
+    is_not_schedule: Union[Unset, None, bool] = UNSET,
+) -> Optional[List[Union["ListJobsResponse200ItemType0", "ListJobsResponse200ItemType1"]]]:
     """list all jobs
 
     Args:
         workspace (str):
         created_by (Union[Unset, None, str]):
+        label (Union[Unset, None, str]):
         parent_job (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
@@ -274,24 +322,28 @@ def sync(
         args (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
+        page (Union[Unset, None, int]):
+        per_page (Union[Unset, None, int]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
         has_null_parent (Union[Unset, None, bool]):
         success (Union[Unset, None, bool]):
         all_workspaces (Union[Unset, None, bool]):
+        is_not_schedule (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        List['ListJobsResponse200Item']
+        List[Union['ListJobsResponse200ItemType0', 'ListJobsResponse200ItemType1']]
     """
 
     return sync_detailed(
         workspace=workspace,
         client=client,
         created_by=created_by,
+        label=label,
         parent_job=parent_job,
         script_path_exact=script_path_exact,
         script_path_start=script_path_start,
@@ -307,11 +359,14 @@ def sync(
         args=args,
         tag=tag,
         result=result,
+        page=page,
+        per_page=per_page,
         is_skipped=is_skipped,
         is_flow_step=is_flow_step,
         has_null_parent=has_null_parent,
         success=success,
         all_workspaces=all_workspaces,
+        is_not_schedule=is_not_schedule,
     ).parsed
 
 
@@ -320,6 +375,7 @@ async def asyncio_detailed(
     *,
     client: Union[AuthenticatedClient, Client],
     created_by: Union[Unset, None, str] = UNSET,
+    label: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
@@ -335,17 +391,21 @@ async def asyncio_detailed(
     args: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     has_null_parent: Union[Unset, None, bool] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
     all_workspaces: Union[Unset, None, bool] = UNSET,
-) -> Response[List["ListJobsResponse200Item"]]:
+    is_not_schedule: Union[Unset, None, bool] = UNSET,
+) -> Response[List[Union["ListJobsResponse200ItemType0", "ListJobsResponse200ItemType1"]]]:
     """list all jobs
 
     Args:
         workspace (str):
         created_by (Union[Unset, None, str]):
+        label (Union[Unset, None, str]):
         parent_job (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
@@ -361,23 +421,27 @@ async def asyncio_detailed(
         args (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
+        page (Union[Unset, None, int]):
+        per_page (Union[Unset, None, int]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
         has_null_parent (Union[Unset, None, bool]):
         success (Union[Unset, None, bool]):
         all_workspaces (Union[Unset, None, bool]):
+        is_not_schedule (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[List['ListJobsResponse200Item']]
+        Response[List[Union['ListJobsResponse200ItemType0', 'ListJobsResponse200ItemType1']]]
     """
 
     kwargs = _get_kwargs(
         workspace=workspace,
         created_by=created_by,
+        label=label,
         parent_job=parent_job,
         script_path_exact=script_path_exact,
         script_path_start=script_path_start,
@@ -393,11 +457,14 @@ async def asyncio_detailed(
         args=args,
         tag=tag,
         result=result,
+        page=page,
+        per_page=per_page,
         is_skipped=is_skipped,
         is_flow_step=is_flow_step,
         has_null_parent=has_null_parent,
         success=success,
         all_workspaces=all_workspaces,
+        is_not_schedule=is_not_schedule,
     )
 
     response = await client.get_async_httpx_client().request(**kwargs)
@@ -410,6 +477,7 @@ async def asyncio(
     *,
     client: Union[AuthenticatedClient, Client],
     created_by: Union[Unset, None, str] = UNSET,
+    label: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
@@ -425,17 +493,21 @@ async def asyncio(
     args: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     has_null_parent: Union[Unset, None, bool] = UNSET,
     success: Union[Unset, None, bool] = UNSET,
     all_workspaces: Union[Unset, None, bool] = UNSET,
-) -> Optional[List["ListJobsResponse200Item"]]:
+    is_not_schedule: Union[Unset, None, bool] = UNSET,
+) -> Optional[List[Union["ListJobsResponse200ItemType0", "ListJobsResponse200ItemType1"]]]:
     """list all jobs
 
     Args:
         workspace (str):
         created_by (Union[Unset, None, str]):
+        label (Union[Unset, None, str]):
         parent_job (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
@@ -451,18 +523,21 @@ async def asyncio(
         args (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
+        page (Union[Unset, None, int]):
+        per_page (Union[Unset, None, int]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
         has_null_parent (Union[Unset, None, bool]):
         success (Union[Unset, None, bool]):
         all_workspaces (Union[Unset, None, bool]):
+        is_not_schedule (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        List['ListJobsResponse200Item']
+        List[Union['ListJobsResponse200ItemType0', 'ListJobsResponse200ItemType1']]
     """
 
     return (
@@ -470,6 +545,7 @@ async def asyncio(
             workspace=workspace,
             client=client,
             created_by=created_by,
+            label=label,
             parent_job=parent_job,
             script_path_exact=script_path_exact,
             script_path_start=script_path_start,
@@ -485,10 +561,13 @@ async def asyncio(
             args=args,
             tag=tag,
             result=result,
+            page=page,
+            per_page=per_page,
             is_skipped=is_skipped,
             is_flow_step=is_flow_step,
             has_null_parent=has_null_parent,
             success=success,
             all_workspaces=all_workspaces,
+            is_not_schedule=is_not_schedule,
         )
     ).parsed
