@@ -30,7 +30,10 @@ def _get_kwargs(
     args: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
     all_workspaces: Union[Unset, None, bool] = UNSET,
+    is_not_schedule: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
     pass
 
@@ -77,8 +80,14 @@ def _get_kwargs(
 
     params["tag"] = tag
 
+    params["page"] = page
+
+    params["per_page"] = per_page
+
     params["all_workspaces"] = all_workspaces
 
+    params["is_not_schedule"] = is_not_schedule
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     return {
@@ -140,7 +149,10 @@ def sync_detailed(
     args: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
     all_workspaces: Union[Unset, None, bool] = UNSET,
+    is_not_schedule: Union[Unset, None, bool] = UNSET,
 ) -> Response[List["ListQueueResponse200Item"]]:
     """list all queued jobs
 
@@ -163,7 +175,10 @@ def sync_detailed(
         args (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
+        page (Union[Unset, None, int]):
+        per_page (Union[Unset, None, int]):
         all_workspaces (Union[Unset, None, bool]):
+        is_not_schedule (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -192,7 +207,10 @@ def sync_detailed(
         args=args,
         result=result,
         tag=tag,
+        page=page,
+        per_page=per_page,
         all_workspaces=all_workspaces,
+        is_not_schedule=is_not_schedule,
     )
 
     response = client.get_httpx_client().request(
@@ -223,7 +241,10 @@ def sync(
     args: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
     all_workspaces: Union[Unset, None, bool] = UNSET,
+    is_not_schedule: Union[Unset, None, bool] = UNSET,
 ) -> Optional[List["ListQueueResponse200Item"]]:
     """list all queued jobs
 
@@ -246,7 +267,10 @@ def sync(
         args (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
+        page (Union[Unset, None, int]):
+        per_page (Union[Unset, None, int]):
         all_workspaces (Union[Unset, None, bool]):
+        is_not_schedule (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -276,7 +300,10 @@ def sync(
         args=args,
         result=result,
         tag=tag,
+        page=page,
+        per_page=per_page,
         all_workspaces=all_workspaces,
+        is_not_schedule=is_not_schedule,
     ).parsed
 
 
@@ -301,7 +328,10 @@ async def asyncio_detailed(
     args: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
     all_workspaces: Union[Unset, None, bool] = UNSET,
+    is_not_schedule: Union[Unset, None, bool] = UNSET,
 ) -> Response[List["ListQueueResponse200Item"]]:
     """list all queued jobs
 
@@ -324,7 +354,10 @@ async def asyncio_detailed(
         args (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
+        page (Union[Unset, None, int]):
+        per_page (Union[Unset, None, int]):
         all_workspaces (Union[Unset, None, bool]):
+        is_not_schedule (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -353,7 +386,10 @@ async def asyncio_detailed(
         args=args,
         result=result,
         tag=tag,
+        page=page,
+        per_page=per_page,
         all_workspaces=all_workspaces,
+        is_not_schedule=is_not_schedule,
     )
 
     response = await client.get_async_httpx_client().request(**kwargs)
@@ -382,7 +418,10 @@ async def asyncio(
     args: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
+    page: Union[Unset, None, int] = UNSET,
+    per_page: Union[Unset, None, int] = UNSET,
     all_workspaces: Union[Unset, None, bool] = UNSET,
+    is_not_schedule: Union[Unset, None, bool] = UNSET,
 ) -> Optional[List["ListQueueResponse200Item"]]:
     """list all queued jobs
 
@@ -405,7 +444,10 @@ async def asyncio(
         args (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
+        page (Union[Unset, None, int]):
+        per_page (Union[Unset, None, int]):
         all_workspaces (Union[Unset, None, bool]):
+        is_not_schedule (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -436,6 +478,9 @@ async def asyncio(
             args=args,
             result=result,
             tag=tag,
+            page=page,
+            per_page=per_page,
             all_workspaces=all_workspaces,
+            is_not_schedule=is_not_schedule,
         )
     ).parsed
