@@ -19,6 +19,7 @@ def _get_kwargs(
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
+    cache_ttl: Union[Unset, None, str] = UNSET,
     job_id: Union[Unset, None, str] = UNSET,
     invisible_to_owner: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
@@ -37,6 +38,8 @@ def _get_kwargs(
 
     params["tag"] = tag
 
+    params["cache_ttl"] = cache_ttl
+
     params["job_id"] = job_id
 
     params["invisible_to_owner"] = invisible_to_owner
@@ -82,6 +85,7 @@ def sync_detailed(
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
+    cache_ttl: Union[Unset, None, str] = UNSET,
     job_id: Union[Unset, None, str] = UNSET,
     invisible_to_owner: Union[Unset, None, bool] = UNSET,
 ) -> Response[Any]:
@@ -94,6 +98,7 @@ def sync_detailed(
         scheduled_in_secs (Union[Unset, None, int]):
         parent_job (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
+        cache_ttl (Union[Unset, None, str]):
         job_id (Union[Unset, None, str]):
         invisible_to_owner (Union[Unset, None, bool]):
         json_body (RunScriptByPathJsonBody):
@@ -114,6 +119,7 @@ def sync_detailed(
         scheduled_in_secs=scheduled_in_secs,
         parent_job=parent_job,
         tag=tag,
+        cache_ttl=cache_ttl,
         job_id=job_id,
         invisible_to_owner=invisible_to_owner,
     )
@@ -135,6 +141,7 @@ async def asyncio_detailed(
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
+    cache_ttl: Union[Unset, None, str] = UNSET,
     job_id: Union[Unset, None, str] = UNSET,
     invisible_to_owner: Union[Unset, None, bool] = UNSET,
 ) -> Response[Any]:
@@ -147,6 +154,7 @@ async def asyncio_detailed(
         scheduled_in_secs (Union[Unset, None, int]):
         parent_job (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
+        cache_ttl (Union[Unset, None, str]):
         job_id (Union[Unset, None, str]):
         invisible_to_owner (Union[Unset, None, bool]):
         json_body (RunScriptByPathJsonBody):
@@ -167,6 +175,7 @@ async def asyncio_detailed(
         scheduled_in_secs=scheduled_in_secs,
         parent_job=parent_job,
         tag=tag,
+        cache_ttl=cache_ttl,
         job_id=job_id,
         invisible_to_owner=invisible_to_owner,
     )
