@@ -1,8 +1,10 @@
-from typing import Any, Dict, Optional
+from http import HTTPStatus
+from typing import Any, Dict, Optional, Union
 
 import httpx
 
-from ...client import Client
+from ... import errors
+from ...client import AuthenticatedClient, Client
 from ...models.delete_script_by_hash_response_200 import DeleteScriptByHashResponse200
 from ...types import Response
 
@@ -10,37 +12,39 @@ from ...types import Response
 def _get_kwargs(
     workspace: str,
     hash_: str,
-    *,
-    client: Client,
 ) -> Dict[str, Any]:
-    url = "{}/w/{workspace}/scripts/delete/h/{hash}".format(client.base_url, workspace=workspace, hash=hash_)
-
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
+    pass
 
     return {
         "method": "post",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
+        "url": "/w/{workspace}/scripts/delete/h/{hash}".format(
+            workspace=workspace,
+            hash=hash_,
+        ),
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[DeleteScriptByHashResponse200]:
-    if response.status_code == 200:
+def _parse_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Optional[DeleteScriptByHashResponse200]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = DeleteScriptByHashResponse200.from_dict(response.json())
 
         return response_200
-    return None
+    if client.raise_on_unexpected_status:
+        raise errors.UnexpectedStatus(response.status_code, response.content)
+    else:
+        return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[DeleteScriptByHashResponse200]:
+def _build_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Response[DeleteScriptByHashResponse200]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
-        parsed=_parse_response(response=response),
+        parsed=_parse_response(client=client, response=response),
     )
 
 
@@ -48,7 +52,7 @@ def sync_detailed(
     workspace: str,
     hash_: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
 ) -> Response[DeleteScriptByHashResponse200]:
     """delete script by hash (erase content but keep hash, require admin)
 
@@ -56,6 +60,10 @@ def sync_detailed(
         workspace (str):
         hash_ (str):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[DeleteScriptByHashResponse200]
     """
@@ -63,22 +71,20 @@ def sync_detailed(
     kwargs = _get_kwargs(
         workspace=workspace,
         hash_=hash_,
-        client=client,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 def sync(
     workspace: str,
     hash_: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
 ) -> Optional[DeleteScriptByHashResponse200]:
     """delete script by hash (erase content but keep hash, require admin)
 
@@ -86,8 +92,12 @@ def sync(
         workspace (str):
         hash_ (str):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[DeleteScriptByHashResponse200]
+        DeleteScriptByHashResponse200
     """
 
     return sync_detailed(
@@ -101,7 +111,7 @@ async def asyncio_detailed(
     workspace: str,
     hash_: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
 ) -> Response[DeleteScriptByHashResponse200]:
     """delete script by hash (erase content but keep hash, require admin)
 
@@ -109,6 +119,10 @@ async def asyncio_detailed(
         workspace (str):
         hash_ (str):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
         Response[DeleteScriptByHashResponse200]
     """
@@ -116,20 +130,18 @@ async def asyncio_detailed(
     kwargs = _get_kwargs(
         workspace=workspace,
         hash_=hash_,
-        client=client,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
-    return _build_response(response=response)
+    return _build_response(client=client, response=response)
 
 
 async def asyncio(
     workspace: str,
     hash_: str,
     *,
-    client: Client,
+    client: Union[AuthenticatedClient, Client],
 ) -> Optional[DeleteScriptByHashResponse200]:
     """delete script by hash (erase content but keep hash, require admin)
 
@@ -137,8 +149,12 @@ async def asyncio(
         workspace (str):
         hash_ (str):
 
+    Raises:
+        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
+        httpx.TimeoutException: If the request takes longer than Client.timeout.
+
     Returns:
-        Response[DeleteScriptByHashResponse200]
+        DeleteScriptByHashResponse200
     """
 
     return (
