@@ -11,6 +11,7 @@ from ..types import UNSET, Unset
 if TYPE_CHECKING:
     from ..models.app_with_last_version_w_draft_extra_perms import AppWithLastVersionWDraftExtraPerms
     from ..models.app_with_last_version_w_draft_policy import AppWithLastVersionWDraftPolicy
+    from ..models.app_with_last_version_w_draft_value import AppWithLastVersionWDraftValue
 
 
 T = TypeVar("T", bound="AppWithLastVersionWDraft")
@@ -27,7 +28,7 @@ class AppWithLastVersionWDraft:
         versions (List[int]):
         created_by (str):
         created_at (datetime.datetime):
-        value (Any):
+        value (AppWithLastVersionWDraftValue):
         policy (AppWithLastVersionWDraftPolicy):
         execution_mode (AppWithLastVersionWDraftExecutionMode):
         extra_perms (AppWithLastVersionWDraftExtraPerms):
@@ -42,7 +43,7 @@ class AppWithLastVersionWDraft:
     versions: List[int]
     created_by: str
     created_at: datetime.datetime
-    value: Any
+    value: "AppWithLastVersionWDraftValue"
     policy: "AppWithLastVersionWDraftPolicy"
     execution_mode: AppWithLastVersionWDraftExecutionMode
     extra_perms: "AppWithLastVersionWDraftExtraPerms"
@@ -60,7 +61,8 @@ class AppWithLastVersionWDraft:
         created_by = self.created_by
         created_at = self.created_at.isoformat()
 
-        value = self.value
+        value = self.value.to_dict()
+
         policy = self.policy.to_dict()
 
         execution_mode = self.execution_mode.value
@@ -98,6 +100,7 @@ class AppWithLastVersionWDraft:
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.app_with_last_version_w_draft_extra_perms import AppWithLastVersionWDraftExtraPerms
         from ..models.app_with_last_version_w_draft_policy import AppWithLastVersionWDraftPolicy
+        from ..models.app_with_last_version_w_draft_value import AppWithLastVersionWDraftValue
 
         d = src_dict.copy()
         id = d.pop("id")
@@ -114,7 +117,7 @@ class AppWithLastVersionWDraft:
 
         created_at = isoparse(d.pop("created_at"))
 
-        value = d.pop("value")
+        value = AppWithLastVersionWDraftValue.from_dict(d.pop("value"))
 
         policy = AppWithLastVersionWDraftPolicy.from_dict(d.pop("policy"))
 
