@@ -8,6 +8,9 @@ from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
     from ..models.app_with_last_version_w_draft_policy_triggerables import AppWithLastVersionWDraftPolicyTriggerables
+    from ..models.app_with_last_version_w_draft_policy_triggerables_v2 import (
+        AppWithLastVersionWDraftPolicyTriggerablesV2,
+    )
 
 
 T = TypeVar("T", bound="AppWithLastVersionWDraftPolicy")
@@ -18,12 +21,14 @@ class AppWithLastVersionWDraftPolicy:
     """
     Attributes:
         triggerables (Union[Unset, AppWithLastVersionWDraftPolicyTriggerables]):
+        triggerables_v2 (Union[Unset, AppWithLastVersionWDraftPolicyTriggerablesV2]):
         execution_mode (Union[Unset, AppWithLastVersionWDraftPolicyExecutionMode]):
         on_behalf_of (Union[Unset, str]):
         on_behalf_of_email (Union[Unset, str]):
     """
 
     triggerables: Union[Unset, "AppWithLastVersionWDraftPolicyTriggerables"] = UNSET
+    triggerables_v2: Union[Unset, "AppWithLastVersionWDraftPolicyTriggerablesV2"] = UNSET
     execution_mode: Union[Unset, AppWithLastVersionWDraftPolicyExecutionMode] = UNSET
     on_behalf_of: Union[Unset, str] = UNSET
     on_behalf_of_email: Union[Unset, str] = UNSET
@@ -34,6 +39,10 @@ class AppWithLastVersionWDraftPolicy:
         if not isinstance(self.triggerables, Unset):
             triggerables = self.triggerables.to_dict()
 
+        triggerables_v2: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.triggerables_v2, Unset):
+            triggerables_v2 = self.triggerables_v2.to_dict()
+
         execution_mode: Union[Unset, str] = UNSET
         if not isinstance(self.execution_mode, Unset):
             execution_mode = self.execution_mode.value
@@ -46,6 +55,8 @@ class AppWithLastVersionWDraftPolicy:
         field_dict.update({})
         if triggerables is not UNSET:
             field_dict["triggerables"] = triggerables
+        if triggerables_v2 is not UNSET:
+            field_dict["triggerables_v2"] = triggerables_v2
         if execution_mode is not UNSET:
             field_dict["execution_mode"] = execution_mode
         if on_behalf_of is not UNSET:
@@ -60,6 +71,9 @@ class AppWithLastVersionWDraftPolicy:
         from ..models.app_with_last_version_w_draft_policy_triggerables import (
             AppWithLastVersionWDraftPolicyTriggerables,
         )
+        from ..models.app_with_last_version_w_draft_policy_triggerables_v2 import (
+            AppWithLastVersionWDraftPolicyTriggerablesV2,
+        )
 
         d = src_dict.copy()
         _triggerables = d.pop("triggerables", UNSET)
@@ -69,6 +83,13 @@ class AppWithLastVersionWDraftPolicy:
         else:
             triggerables = AppWithLastVersionWDraftPolicyTriggerables.from_dict(_triggerables)
 
+        _triggerables_v2 = d.pop("triggerables_v2", UNSET)
+        triggerables_v2: Union[Unset, AppWithLastVersionWDraftPolicyTriggerablesV2]
+        if isinstance(_triggerables_v2, Unset):
+            triggerables_v2 = UNSET
+        else:
+            triggerables_v2 = AppWithLastVersionWDraftPolicyTriggerablesV2.from_dict(_triggerables_v2)
+
         _execution_mode = d.pop("execution_mode", UNSET)
         execution_mode: Union[Unset, AppWithLastVersionWDraftPolicyExecutionMode]
         if isinstance(_execution_mode, Unset):
@@ -82,6 +103,7 @@ class AppWithLastVersionWDraftPolicy:
 
         app_with_last_version_w_draft_policy = cls(
             triggerables=triggerables,
+            triggerables_v2=triggerables_v2,
             execution_mode=execution_mode,
             on_behalf_of=on_behalf_of,
             on_behalf_of_email=on_behalf_of_email,
