@@ -31,6 +31,7 @@ class BranchOneBranchesItemModulesItemSuspend:
         user_groups_required (Union['BranchOneBranchesItemModulesItemSuspendUserGroupsRequiredType0',
             'BranchOneBranchesItemModulesItemSuspendUserGroupsRequiredType1', Unset]):
         self_approval_disabled (Union[Unset, bool]):
+        hide_cancel (Union[Unset, bool]):
     """
 
     required_events: Union[Unset, int] = UNSET
@@ -43,6 +44,7 @@ class BranchOneBranchesItemModulesItemSuspend:
         Unset,
     ] = UNSET
     self_approval_disabled: Union[Unset, bool] = UNSET
+    hide_cancel: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -72,6 +74,7 @@ class BranchOneBranchesItemModulesItemSuspend:
                 user_groups_required = self.user_groups_required.to_dict()
 
         self_approval_disabled = self.self_approval_disabled
+        hide_cancel = self.hide_cancel
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -88,6 +91,8 @@ class BranchOneBranchesItemModulesItemSuspend:
             field_dict["user_groups_required"] = user_groups_required
         if self_approval_disabled is not UNSET:
             field_dict["self_approval_disabled"] = self_approval_disabled
+        if hide_cancel is not UNSET:
+            field_dict["hide_cancel"] = hide_cancel
 
         return field_dict
 
@@ -162,6 +167,8 @@ class BranchOneBranchesItemModulesItemSuspend:
 
         self_approval_disabled = d.pop("self_approval_disabled", UNSET)
 
+        hide_cancel = d.pop("hide_cancel", UNSET)
+
         branch_one_branches_item_modules_item_suspend = cls(
             required_events=required_events,
             timeout=timeout,
@@ -169,6 +176,7 @@ class BranchOneBranchesItemModulesItemSuspend:
             user_auth_required=user_auth_required,
             user_groups_required=user_groups_required,
             self_approval_disabled=self_approval_disabled,
+            hide_cancel=hide_cancel,
         )
 
         branch_one_branches_item_modules_item_suspend.additional_properties = d
