@@ -32,6 +32,7 @@ class BranchOneDefaultItem:
         mock (Union[Unset, BranchOneDefaultItemMock]):
         suspend (Union[Unset, BranchOneDefaultItemSuspend]):
         priority (Union[Unset, float]):
+        continue_on_error (Union[Unset, bool]):
         retry (Union[Unset, BranchOneDefaultItemRetry]):
     """
 
@@ -46,6 +47,7 @@ class BranchOneDefaultItem:
     mock: Union[Unset, "BranchOneDefaultItemMock"] = UNSET
     suspend: Union[Unset, "BranchOneDefaultItemSuspend"] = UNSET
     priority: Union[Unset, float] = UNSET
+    continue_on_error: Union[Unset, bool] = UNSET
     retry: Union[Unset, "BranchOneDefaultItemRetry"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
@@ -85,6 +87,7 @@ class BranchOneDefaultItem:
             suspend = self.suspend.to_dict()
 
         priority = self.priority
+        continue_on_error = self.continue_on_error
         retry: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.retry, Unset):
             retry = self.retry.to_dict()
@@ -115,6 +118,8 @@ class BranchOneDefaultItem:
             field_dict["suspend"] = suspend
         if priority is not UNSET:
             field_dict["priority"] = priority
+        if continue_on_error is not UNSET:
+            field_dict["continue_on_error"] = continue_on_error
         if retry is not UNSET:
             field_dict["retry"] = retry
 
@@ -196,6 +201,8 @@ class BranchOneDefaultItem:
 
         priority = d.pop("priority", UNSET)
 
+        continue_on_error = d.pop("continue_on_error", UNSET)
+
         _retry = d.pop("retry", UNSET)
         retry: Union[Unset, BranchOneDefaultItemRetry]
         if isinstance(_retry, Unset):
@@ -215,6 +222,7 @@ class BranchOneDefaultItem:
             mock=mock,
             suspend=suspend,
             priority=priority,
+            continue_on_error=continue_on_error,
             retry=retry,
         )
 
