@@ -29,6 +29,7 @@ class BranchOneDefaultItemSuspend:
         user_groups_required (Union['BranchOneDefaultItemSuspendUserGroupsRequiredType0',
             'BranchOneDefaultItemSuspendUserGroupsRequiredType1', Unset]):
         self_approval_disabled (Union[Unset, bool]):
+        hide_cancel (Union[Unset, bool]):
     """
 
     required_events: Union[Unset, int] = UNSET
@@ -41,6 +42,7 @@ class BranchOneDefaultItemSuspend:
         Unset,
     ] = UNSET
     self_approval_disabled: Union[Unset, bool] = UNSET
+    hide_cancel: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -70,6 +72,7 @@ class BranchOneDefaultItemSuspend:
                 user_groups_required = self.user_groups_required.to_dict()
 
         self_approval_disabled = self.self_approval_disabled
+        hide_cancel = self.hide_cancel
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -86,6 +89,8 @@ class BranchOneDefaultItemSuspend:
             field_dict["user_groups_required"] = user_groups_required
         if self_approval_disabled is not UNSET:
             field_dict["self_approval_disabled"] = self_approval_disabled
+        if hide_cancel is not UNSET:
+            field_dict["hide_cancel"] = hide_cancel
 
         return field_dict
 
@@ -154,6 +159,8 @@ class BranchOneDefaultItemSuspend:
 
         self_approval_disabled = d.pop("self_approval_disabled", UNSET)
 
+        hide_cancel = d.pop("hide_cancel", UNSET)
+
         branch_one_default_item_suspend = cls(
             required_events=required_events,
             timeout=timeout,
@@ -161,6 +168,7 @@ class BranchOneDefaultItemSuspend:
             user_auth_required=user_auth_required,
             user_groups_required=user_groups_required,
             self_approval_disabled=self_approval_disabled,
+            hide_cancel=hide_cancel,
         )
 
         branch_one_default_item_suspend.additional_properties = d
