@@ -1,5 +1,5 @@
 import datetime
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
@@ -54,6 +54,7 @@ class DeleteCompletedJobResponse200:
         language (Union[Unset, DeleteCompletedJobResponse200Language]):
         mem_peak (Union[Unset, int]):
         priority (Union[Unset, int]):
+        labels (Union[Unset, List[str]]):
     """
 
     id: str
@@ -87,6 +88,7 @@ class DeleteCompletedJobResponse200:
     language: Union[Unset, DeleteCompletedJobResponse200Language] = UNSET
     mem_peak: Union[Unset, int] = UNSET
     priority: Union[Unset, int] = UNSET
+    labels: Union[Unset, List[str]] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -136,6 +138,9 @@ class DeleteCompletedJobResponse200:
 
         mem_peak = self.mem_peak
         priority = self.priority
+        labels: Union[Unset, List[str]] = UNSET
+        if not isinstance(self.labels, Unset):
+            labels = self.labels
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -191,6 +196,8 @@ class DeleteCompletedJobResponse200:
             field_dict["mem_peak"] = mem_peak
         if priority is not UNSET:
             field_dict["priority"] = priority
+        if labels is not UNSET:
+            field_dict["labels"] = labels
 
         return field_dict
 
@@ -283,6 +290,8 @@ class DeleteCompletedJobResponse200:
 
         priority = d.pop("priority", UNSET)
 
+        labels = cast(List[str], d.pop("labels", UNSET))
+
         delete_completed_job_response_200 = cls(
             id=id,
             created_by=created_by,
@@ -315,6 +324,7 @@ class DeleteCompletedJobResponse200:
             language=language,
             mem_peak=mem_peak,
             priority=priority,
+            labels=labels,
         )
 
         delete_completed_job_response_200.additional_properties = d
