@@ -27,12 +27,14 @@ class DeleteCompletedJobResponse200FlowStatus:
         step (int):
         modules (List['DeleteCompletedJobResponse200FlowStatusModulesItem']):
         failure_module (DeleteCompletedJobResponse200FlowStatusFailureModule):
+        user_states (Union[Unset, Any]):
         retry (Union[Unset, DeleteCompletedJobResponse200FlowStatusRetry]):
     """
 
     step: int
     modules: List["DeleteCompletedJobResponse200FlowStatusModulesItem"]
     failure_module: "DeleteCompletedJobResponse200FlowStatusFailureModule"
+    user_states: Union[Unset, Any] = UNSET
     retry: Union[Unset, "DeleteCompletedJobResponse200FlowStatusRetry"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
@@ -46,6 +48,7 @@ class DeleteCompletedJobResponse200FlowStatus:
 
         failure_module = self.failure_module.to_dict()
 
+        user_states = self.user_states
         retry: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.retry, Unset):
             retry = self.retry.to_dict()
@@ -59,6 +62,8 @@ class DeleteCompletedJobResponse200FlowStatus:
                 "failure_module": failure_module,
             }
         )
+        if user_states is not UNSET:
+            field_dict["user_states"] = user_states
         if retry is not UNSET:
             field_dict["retry"] = retry
 
@@ -88,6 +93,8 @@ class DeleteCompletedJobResponse200FlowStatus:
 
         failure_module = DeleteCompletedJobResponse200FlowStatusFailureModule.from_dict(d.pop("failure_module"))
 
+        user_states = d.pop("user_states", UNSET)
+
         _retry = d.pop("retry", UNSET)
         retry: Union[Unset, DeleteCompletedJobResponse200FlowStatusRetry]
         if isinstance(_retry, Unset):
@@ -99,6 +106,7 @@ class DeleteCompletedJobResponse200FlowStatus:
             step=step,
             modules=modules,
             failure_module=failure_module,
+            user_states=user_states,
             retry=retry,
         )
 
