@@ -6,6 +6,9 @@ from attrs import field as _attrs_field
 from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
+    from ..models.execute_component_json_body_force_viewer_one_of_fields import (
+        ExecuteComponentJsonBodyForceViewerOneOfFields,
+    )
     from ..models.execute_component_json_body_force_viewer_static_fields import (
         ExecuteComponentJsonBodyForceViewerStaticFields,
     )
@@ -24,6 +27,7 @@ class ExecuteComponentJsonBody:
         path (Union[Unset, str]):
         raw_code (Union[Unset, ExecuteComponentJsonBodyRawCode]):
         force_viewer_static_fields (Union[Unset, ExecuteComponentJsonBodyForceViewerStaticFields]):
+        force_viewer_one_of_fields (Union[Unset, ExecuteComponentJsonBodyForceViewerOneOfFields]):
     """
 
     component: str
@@ -31,6 +35,7 @@ class ExecuteComponentJsonBody:
     path: Union[Unset, str] = UNSET
     raw_code: Union[Unset, "ExecuteComponentJsonBodyRawCode"] = UNSET
     force_viewer_static_fields: Union[Unset, "ExecuteComponentJsonBodyForceViewerStaticFields"] = UNSET
+    force_viewer_one_of_fields: Union[Unset, "ExecuteComponentJsonBodyForceViewerOneOfFields"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -45,6 +50,10 @@ class ExecuteComponentJsonBody:
         if not isinstance(self.force_viewer_static_fields, Unset):
             force_viewer_static_fields = self.force_viewer_static_fields.to_dict()
 
+        force_viewer_one_of_fields: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.force_viewer_one_of_fields, Unset):
+            force_viewer_one_of_fields = self.force_viewer_one_of_fields.to_dict()
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -59,11 +68,16 @@ class ExecuteComponentJsonBody:
             field_dict["raw_code"] = raw_code
         if force_viewer_static_fields is not UNSET:
             field_dict["force_viewer_static_fields"] = force_viewer_static_fields
+        if force_viewer_one_of_fields is not UNSET:
+            field_dict["force_viewer_one_of_fields"] = force_viewer_one_of_fields
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.execute_component_json_body_force_viewer_one_of_fields import (
+            ExecuteComponentJsonBodyForceViewerOneOfFields,
+        )
         from ..models.execute_component_json_body_force_viewer_static_fields import (
             ExecuteComponentJsonBodyForceViewerStaticFields,
         )
@@ -92,12 +106,22 @@ class ExecuteComponentJsonBody:
                 _force_viewer_static_fields
             )
 
+        _force_viewer_one_of_fields = d.pop("force_viewer_one_of_fields", UNSET)
+        force_viewer_one_of_fields: Union[Unset, ExecuteComponentJsonBodyForceViewerOneOfFields]
+        if isinstance(_force_viewer_one_of_fields, Unset):
+            force_viewer_one_of_fields = UNSET
+        else:
+            force_viewer_one_of_fields = ExecuteComponentJsonBodyForceViewerOneOfFields.from_dict(
+                _force_viewer_one_of_fields
+            )
+
         execute_component_json_body = cls(
             component=component,
             args=args,
             path=path,
             raw_code=raw_code,
             force_viewer_static_fields=force_viewer_static_fields,
+            force_viewer_one_of_fields=force_viewer_one_of_fields,
         )
 
         execute_component_json_body.additional_properties = d
