@@ -24,7 +24,6 @@ class FlowMetadata:
         archived (bool):
         extra_perms (FlowMetadataExtraPerms):
         workspace_id (Union[Unset, str]):
-        additional_properties (Union[Unset, bool]):
         starred (Union[Unset, bool]):
         draft_only (Union[Unset, bool]):
         tag (Union[Unset, str]):
@@ -32,6 +31,7 @@ class FlowMetadata:
         priority (Union[Unset, int]):
         dedicated_worker (Union[Unset, bool]):
         timeout (Union[Unset, float]):
+        visible_to_runner_only (Union[Unset, bool]):
     """
 
     path: str
@@ -40,7 +40,6 @@ class FlowMetadata:
     archived: bool
     extra_perms: "FlowMetadataExtraPerms"
     workspace_id: Union[Unset, str] = UNSET
-    additional_properties: Union[Unset, bool] = UNSET
     starred: Union[Unset, bool] = UNSET
     draft_only: Union[Unset, bool] = UNSET
     tag: Union[Unset, str] = UNSET
@@ -48,6 +47,7 @@ class FlowMetadata:
     priority: Union[Unset, int] = UNSET
     dedicated_worker: Union[Unset, bool] = UNSET
     timeout: Union[Unset, float] = UNSET
+    visible_to_runner_only: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -59,7 +59,6 @@ class FlowMetadata:
         extra_perms = self.extra_perms.to_dict()
 
         workspace_id = self.workspace_id
-        additional_properties = self.additional_properties
         starred = self.starred
         draft_only = self.draft_only
         tag = self.tag
@@ -67,6 +66,7 @@ class FlowMetadata:
         priority = self.priority
         dedicated_worker = self.dedicated_worker
         timeout = self.timeout
+        visible_to_runner_only = self.visible_to_runner_only
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -81,8 +81,6 @@ class FlowMetadata:
         )
         if workspace_id is not UNSET:
             field_dict["workspace_id"] = workspace_id
-        if additional_properties is not UNSET:
-            field_dict["additionalProperties"] = additional_properties
         if starred is not UNSET:
             field_dict["starred"] = starred
         if draft_only is not UNSET:
@@ -97,6 +95,8 @@ class FlowMetadata:
             field_dict["dedicated_worker"] = dedicated_worker
         if timeout is not UNSET:
             field_dict["timeout"] = timeout
+        if visible_to_runner_only is not UNSET:
+            field_dict["visible_to_runner_only"] = visible_to_runner_only
 
         return field_dict
 
@@ -117,8 +117,6 @@ class FlowMetadata:
 
         workspace_id = d.pop("workspace_id", UNSET)
 
-        additional_properties = d.pop("additionalProperties", UNSET)
-
         starred = d.pop("starred", UNSET)
 
         draft_only = d.pop("draft_only", UNSET)
@@ -133,6 +131,8 @@ class FlowMetadata:
 
         timeout = d.pop("timeout", UNSET)
 
+        visible_to_runner_only = d.pop("visible_to_runner_only", UNSET)
+
         flow_metadata = cls(
             path=path,
             edited_by=edited_by,
@@ -140,7 +140,6 @@ class FlowMetadata:
             archived=archived,
             extra_perms=extra_perms,
             workspace_id=workspace_id,
-            additional_properties=additional_properties,
             starred=starred,
             draft_only=draft_only,
             tag=tag,
@@ -148,6 +147,7 @@ class FlowMetadata:
             priority=priority,
             dedicated_worker=dedicated_worker,
             timeout=timeout,
+            visible_to_runner_only=visible_to_runner_only,
         )
 
         flow_metadata.additional_properties = d
