@@ -25,6 +25,7 @@ class FlowModuleSuspend:
         user_groups_required (Union['FlowModuleSuspendUserGroupsRequiredType0',
             'FlowModuleSuspendUserGroupsRequiredType1', Unset]):
         self_approval_disabled (Union[Unset, bool]):
+        hide_cancel (Union[Unset, bool]):
     """
 
     required_events: Union[Unset, int] = UNSET
@@ -35,6 +36,7 @@ class FlowModuleSuspend:
         "FlowModuleSuspendUserGroupsRequiredType0", "FlowModuleSuspendUserGroupsRequiredType1", Unset
     ] = UNSET
     self_approval_disabled: Union[Unset, bool] = UNSET
+    hide_cancel: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -62,6 +64,7 @@ class FlowModuleSuspend:
                 user_groups_required = self.user_groups_required.to_dict()
 
         self_approval_disabled = self.self_approval_disabled
+        hide_cancel = self.hide_cancel
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -78,6 +81,8 @@ class FlowModuleSuspend:
             field_dict["user_groups_required"] = user_groups_required
         if self_approval_disabled is not UNSET:
             field_dict["self_approval_disabled"] = self_approval_disabled
+        if hide_cancel is not UNSET:
+            field_dict["hide_cancel"] = hide_cancel
 
         return field_dict
 
@@ -138,6 +143,8 @@ class FlowModuleSuspend:
 
         self_approval_disabled = d.pop("self_approval_disabled", UNSET)
 
+        hide_cancel = d.pop("hide_cancel", UNSET)
+
         flow_module_suspend = cls(
             required_events=required_events,
             timeout=timeout,
@@ -145,6 +152,7 @@ class FlowModuleSuspend:
             user_auth_required=user_auth_required,
             user_groups_required=user_groups_required,
             self_approval_disabled=self_approval_disabled,
+            hide_cancel=hide_cancel,
         )
 
         flow_module_suspend.additional_properties = d
