@@ -2,7 +2,7 @@ from enum import Enum
 
 
 class FlowModuleValue2Type6Type(str, Enum):
-    IDENTITY = "identity"
+    BRANCHALL = "branchall"
 
     def __str__(self) -> str:
         return str(self.value)
