@@ -13,6 +13,7 @@ from ..types import UNSET, Unset
 if TYPE_CHECKING:
     from ..models.get_app_by_path_with_draft_response_200_extra_perms import GetAppByPathWithDraftResponse200ExtraPerms
     from ..models.get_app_by_path_with_draft_response_200_policy import GetAppByPathWithDraftResponse200Policy
+    from ..models.get_app_by_path_with_draft_response_200_value import GetAppByPathWithDraftResponse200Value
 
 
 T = TypeVar("T", bound="GetAppByPathWithDraftResponse200")
@@ -29,7 +30,7 @@ class GetAppByPathWithDraftResponse200:
         versions (List[int]):
         created_by (str):
         created_at (datetime.datetime):
-        value (Any):
+        value (GetAppByPathWithDraftResponse200Value):
         policy (GetAppByPathWithDraftResponse200Policy):
         execution_mode (GetAppByPathWithDraftResponse200ExecutionMode):
         extra_perms (GetAppByPathWithDraftResponse200ExtraPerms):
@@ -44,7 +45,7 @@ class GetAppByPathWithDraftResponse200:
     versions: List[int]
     created_by: str
     created_at: datetime.datetime
-    value: Any
+    value: "GetAppByPathWithDraftResponse200Value"
     policy: "GetAppByPathWithDraftResponse200Policy"
     execution_mode: GetAppByPathWithDraftResponse200ExecutionMode
     extra_perms: "GetAppByPathWithDraftResponse200ExtraPerms"
@@ -62,7 +63,8 @@ class GetAppByPathWithDraftResponse200:
         created_by = self.created_by
         created_at = self.created_at.isoformat()
 
-        value = self.value
+        value = self.value.to_dict()
+
         policy = self.policy.to_dict()
 
         execution_mode = self.execution_mode.value
@@ -102,6 +104,7 @@ class GetAppByPathWithDraftResponse200:
             GetAppByPathWithDraftResponse200ExtraPerms,
         )
         from ..models.get_app_by_path_with_draft_response_200_policy import GetAppByPathWithDraftResponse200Policy
+        from ..models.get_app_by_path_with_draft_response_200_value import GetAppByPathWithDraftResponse200Value
 
         d = src_dict.copy()
         id = d.pop("id")
@@ -118,7 +121,7 @@ class GetAppByPathWithDraftResponse200:
 
         created_at = isoparse(d.pop("created_at"))
 
-        value = d.pop("value")
+        value = GetAppByPathWithDraftResponse200Value.from_dict(d.pop("value"))
 
         policy = GetAppByPathWithDraftResponse200Policy.from_dict(d.pop("policy"))
 
