@@ -12,6 +12,9 @@ if TYPE_CHECKING:
     from ..models.get_app_by_path_with_draft_response_200_policy_triggerables import (
         GetAppByPathWithDraftResponse200PolicyTriggerables,
     )
+    from ..models.get_app_by_path_with_draft_response_200_policy_triggerables_v2 import (
+        GetAppByPathWithDraftResponse200PolicyTriggerablesV2,
+    )
 
 
 T = TypeVar("T", bound="GetAppByPathWithDraftResponse200Policy")
@@ -22,12 +25,14 @@ class GetAppByPathWithDraftResponse200Policy:
     """
     Attributes:
         triggerables (Union[Unset, GetAppByPathWithDraftResponse200PolicyTriggerables]):
+        triggerables_v2 (Union[Unset, GetAppByPathWithDraftResponse200PolicyTriggerablesV2]):
         execution_mode (Union[Unset, GetAppByPathWithDraftResponse200PolicyExecutionMode]):
         on_behalf_of (Union[Unset, str]):
         on_behalf_of_email (Union[Unset, str]):
     """
 
     triggerables: Union[Unset, "GetAppByPathWithDraftResponse200PolicyTriggerables"] = UNSET
+    triggerables_v2: Union[Unset, "GetAppByPathWithDraftResponse200PolicyTriggerablesV2"] = UNSET
     execution_mode: Union[Unset, GetAppByPathWithDraftResponse200PolicyExecutionMode] = UNSET
     on_behalf_of: Union[Unset, str] = UNSET
     on_behalf_of_email: Union[Unset, str] = UNSET
@@ -38,6 +43,10 @@ class GetAppByPathWithDraftResponse200Policy:
         if not isinstance(self.triggerables, Unset):
             triggerables = self.triggerables.to_dict()
 
+        triggerables_v2: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.triggerables_v2, Unset):
+            triggerables_v2 = self.triggerables_v2.to_dict()
+
         execution_mode: Union[Unset, str] = UNSET
         if not isinstance(self.execution_mode, Unset):
             execution_mode = self.execution_mode.value
@@ -50,6 +59,8 @@ class GetAppByPathWithDraftResponse200Policy:
         field_dict.update({})
         if triggerables is not UNSET:
             field_dict["triggerables"] = triggerables
+        if triggerables_v2 is not UNSET:
+            field_dict["triggerables_v2"] = triggerables_v2
         if execution_mode is not UNSET:
             field_dict["execution_mode"] = execution_mode
         if on_behalf_of is not UNSET:
@@ -64,6 +75,9 @@ class GetAppByPathWithDraftResponse200Policy:
         from ..models.get_app_by_path_with_draft_response_200_policy_triggerables import (
             GetAppByPathWithDraftResponse200PolicyTriggerables,
         )
+        from ..models.get_app_by_path_with_draft_response_200_policy_triggerables_v2 import (
+            GetAppByPathWithDraftResponse200PolicyTriggerablesV2,
+        )
 
         d = src_dict.copy()
         _triggerables = d.pop("triggerables", UNSET)
@@ -73,6 +87,13 @@ class GetAppByPathWithDraftResponse200Policy:
         else:
             triggerables = GetAppByPathWithDraftResponse200PolicyTriggerables.from_dict(_triggerables)
 
+        _triggerables_v2 = d.pop("triggerables_v2", UNSET)
+        triggerables_v2: Union[Unset, GetAppByPathWithDraftResponse200PolicyTriggerablesV2]
+        if isinstance(_triggerables_v2, Unset):
+            triggerables_v2 = UNSET
+        else:
+            triggerables_v2 = GetAppByPathWithDraftResponse200PolicyTriggerablesV2.from_dict(_triggerables_v2)
+
         _execution_mode = d.pop("execution_mode", UNSET)
         execution_mode: Union[Unset, GetAppByPathWithDraftResponse200PolicyExecutionMode]
         if isinstance(_execution_mode, Unset):
@@ -86,6 +107,7 @@ class GetAppByPathWithDraftResponse200Policy:
 
         get_app_by_path_with_draft_response_200_policy = cls(
             triggerables=triggerables,
+            triggerables_v2=triggerables_v2,
             execution_mode=execution_mode,
             on_behalf_of=on_behalf_of,
             on_behalf_of_email=on_behalf_of_email,
