@@ -1,28 +1,32 @@
-from typing import Any, Dict, List, Type, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
-from ..models.get_completed_job_response_200_flow_status_failure_module_approvers_item import (
-    GetCompletedJobResponse200FlowStatusFailureModuleApproversItem,
-)
-from ..models.get_completed_job_response_200_flow_status_failure_module_branch_chosen import (
-    GetCompletedJobResponse200FlowStatusFailureModuleBranchChosen,
-)
-from ..models.get_completed_job_response_200_flow_status_failure_module_branchall import (
-    GetCompletedJobResponse200FlowStatusFailureModuleBranchall,
-)
-from ..models.get_completed_job_response_200_flow_status_failure_module_iterator import (
-    GetCompletedJobResponse200FlowStatusFailureModuleIterator,
-)
 from ..models.get_completed_job_response_200_flow_status_failure_module_type import (
     GetCompletedJobResponse200FlowStatusFailureModuleType,
 )
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.get_completed_job_response_200_flow_status_failure_module_approvers_item import (
+        GetCompletedJobResponse200FlowStatusFailureModuleApproversItem,
+    )
+    from ..models.get_completed_job_response_200_flow_status_failure_module_branch_chosen import (
+        GetCompletedJobResponse200FlowStatusFailureModuleBranchChosen,
+    )
+    from ..models.get_completed_job_response_200_flow_status_failure_module_branchall import (
+        GetCompletedJobResponse200FlowStatusFailureModuleBranchall,
+    )
+    from ..models.get_completed_job_response_200_flow_status_failure_module_iterator import (
+        GetCompletedJobResponse200FlowStatusFailureModuleIterator,
+    )
+
+
 T = TypeVar("T", bound="GetCompletedJobResponse200FlowStatusFailureModule")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class GetCompletedJobResponse200FlowStatusFailureModule:
     """
     Attributes:
@@ -34,7 +38,7 @@ class GetCompletedJobResponse200FlowStatusFailureModule:
         flow_jobs (Union[Unset, List[str]]):
         branch_chosen (Union[Unset, GetCompletedJobResponse200FlowStatusFailureModuleBranchChosen]):
         branchall (Union[Unset, GetCompletedJobResponse200FlowStatusFailureModuleBranchall]):
-        approvers (Union[Unset, List[GetCompletedJobResponse200FlowStatusFailureModuleApproversItem]]):
+        approvers (Union[Unset, List['GetCompletedJobResponse200FlowStatusFailureModuleApproversItem']]):
         parent_module (Union[Unset, str]):
     """
 
@@ -42,13 +46,13 @@ class GetCompletedJobResponse200FlowStatusFailureModule:
     id: Union[Unset, str] = UNSET
     job: Union[Unset, str] = UNSET
     count: Union[Unset, int] = UNSET
-    iterator: Union[Unset, GetCompletedJobResponse200FlowStatusFailureModuleIterator] = UNSET
+    iterator: Union[Unset, "GetCompletedJobResponse200FlowStatusFailureModuleIterator"] = UNSET
     flow_jobs: Union[Unset, List[str]] = UNSET
-    branch_chosen: Union[Unset, GetCompletedJobResponse200FlowStatusFailureModuleBranchChosen] = UNSET
-    branchall: Union[Unset, GetCompletedJobResponse200FlowStatusFailureModuleBranchall] = UNSET
-    approvers: Union[Unset, List[GetCompletedJobResponse200FlowStatusFailureModuleApproversItem]] = UNSET
+    branch_chosen: Union[Unset, "GetCompletedJobResponse200FlowStatusFailureModuleBranchChosen"] = UNSET
+    branchall: Union[Unset, "GetCompletedJobResponse200FlowStatusFailureModuleBranchall"] = UNSET
+    approvers: Union[Unset, List["GetCompletedJobResponse200FlowStatusFailureModuleApproversItem"]] = UNSET
     parent_module: Union[Unset, str] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         type = self.type.value
@@ -112,6 +116,19 @@ class GetCompletedJobResponse200FlowStatusFailureModule:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.get_completed_job_response_200_flow_status_failure_module_approvers_item import (
+            GetCompletedJobResponse200FlowStatusFailureModuleApproversItem,
+        )
+        from ..models.get_completed_job_response_200_flow_status_failure_module_branch_chosen import (
+            GetCompletedJobResponse200FlowStatusFailureModuleBranchChosen,
+        )
+        from ..models.get_completed_job_response_200_flow_status_failure_module_branchall import (
+            GetCompletedJobResponse200FlowStatusFailureModuleBranchall,
+        )
+        from ..models.get_completed_job_response_200_flow_status_failure_module_iterator import (
+            GetCompletedJobResponse200FlowStatusFailureModuleIterator,
+        )
+
         d = src_dict.copy()
         type = GetCompletedJobResponse200FlowStatusFailureModuleType(d.pop("type"))
 
