@@ -30,7 +30,6 @@ class GetFlowByPathResponse200:
         description (Union[Unset, str]):
         schema (Union[Unset, GetFlowByPathResponse200Schema]):
         workspace_id (Union[Unset, str]):
-        additional_properties (Union[Unset, bool]):
         starred (Union[Unset, bool]):
         draft_only (Union[Unset, bool]):
         tag (Union[Unset, str]):
@@ -38,6 +37,7 @@ class GetFlowByPathResponse200:
         priority (Union[Unset, int]):
         dedicated_worker (Union[Unset, bool]):
         timeout (Union[Unset, float]):
+        visible_to_runner_only (Union[Unset, bool]):
     """
 
     summary: str
@@ -50,7 +50,6 @@ class GetFlowByPathResponse200:
     description: Union[Unset, str] = UNSET
     schema: Union[Unset, "GetFlowByPathResponse200Schema"] = UNSET
     workspace_id: Union[Unset, str] = UNSET
-    additional_properties: Union[Unset, bool] = UNSET
     starred: Union[Unset, bool] = UNSET
     draft_only: Union[Unset, bool] = UNSET
     tag: Union[Unset, str] = UNSET
@@ -58,6 +57,7 @@ class GetFlowByPathResponse200:
     priority: Union[Unset, int] = UNSET
     dedicated_worker: Union[Unset, bool] = UNSET
     timeout: Union[Unset, float] = UNSET
+    visible_to_runner_only: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -77,7 +77,6 @@ class GetFlowByPathResponse200:
             schema = self.schema.to_dict()
 
         workspace_id = self.workspace_id
-        additional_properties = self.additional_properties
         starred = self.starred
         draft_only = self.draft_only
         tag = self.tag
@@ -85,6 +84,7 @@ class GetFlowByPathResponse200:
         priority = self.priority
         dedicated_worker = self.dedicated_worker
         timeout = self.timeout
+        visible_to_runner_only = self.visible_to_runner_only
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -105,8 +105,6 @@ class GetFlowByPathResponse200:
             field_dict["schema"] = schema
         if workspace_id is not UNSET:
             field_dict["workspace_id"] = workspace_id
-        if additional_properties is not UNSET:
-            field_dict["additionalProperties"] = additional_properties
         if starred is not UNSET:
             field_dict["starred"] = starred
         if draft_only is not UNSET:
@@ -121,6 +119,8 @@ class GetFlowByPathResponse200:
             field_dict["dedicated_worker"] = dedicated_worker
         if timeout is not UNSET:
             field_dict["timeout"] = timeout
+        if visible_to_runner_only is not UNSET:
+            field_dict["visible_to_runner_only"] = visible_to_runner_only
 
         return field_dict
 
@@ -156,8 +156,6 @@ class GetFlowByPathResponse200:
 
         workspace_id = d.pop("workspace_id", UNSET)
 
-        additional_properties = d.pop("additionalProperties", UNSET)
-
         starred = d.pop("starred", UNSET)
 
         draft_only = d.pop("draft_only", UNSET)
@@ -172,6 +170,8 @@ class GetFlowByPathResponse200:
 
         timeout = d.pop("timeout", UNSET)
 
+        visible_to_runner_only = d.pop("visible_to_runner_only", UNSET)
+
         get_flow_by_path_response_200 = cls(
             summary=summary,
             value=value,
@@ -183,7 +183,6 @@ class GetFlowByPathResponse200:
             description=description,
             schema=schema,
             workspace_id=workspace_id,
-            additional_properties=additional_properties,
             starred=starred,
             draft_only=draft_only,
             tag=tag,
@@ -191,6 +190,7 @@ class GetFlowByPathResponse200:
             priority=priority,
             dedicated_worker=dedicated_worker,
             timeout=timeout,
+            visible_to_runner_only=visible_to_runner_only,
         )
 
         get_flow_by_path_response_200.additional_properties = d
