@@ -45,6 +45,7 @@ class GetFlowByPathResponse200ValueFailureModule:
         mock (Union[Unset, GetFlowByPathResponse200ValueFailureModuleMock]):
         suspend (Union[Unset, GetFlowByPathResponse200ValueFailureModuleSuspend]):
         priority (Union[Unset, float]):
+        continue_on_error (Union[Unset, bool]):
         retry (Union[Unset, GetFlowByPathResponse200ValueFailureModuleRetry]):
     """
 
@@ -63,6 +64,7 @@ class GetFlowByPathResponse200ValueFailureModule:
     mock: Union[Unset, "GetFlowByPathResponse200ValueFailureModuleMock"] = UNSET
     suspend: Union[Unset, "GetFlowByPathResponse200ValueFailureModuleSuspend"] = UNSET
     priority: Union[Unset, float] = UNSET
+    continue_on_error: Union[Unset, bool] = UNSET
     retry: Union[Unset, "GetFlowByPathResponse200ValueFailureModuleRetry"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
@@ -104,6 +106,7 @@ class GetFlowByPathResponse200ValueFailureModule:
             suspend = self.suspend.to_dict()
 
         priority = self.priority
+        continue_on_error = self.continue_on_error
         retry: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.retry, Unset):
             retry = self.retry.to_dict()
@@ -134,6 +137,8 @@ class GetFlowByPathResponse200ValueFailureModule:
             field_dict["suspend"] = suspend
         if priority is not UNSET:
             field_dict["priority"] = priority
+        if continue_on_error is not UNSET:
+            field_dict["continue_on_error"] = continue_on_error
         if retry is not UNSET:
             field_dict["retry"] = retry
 
@@ -231,6 +236,8 @@ class GetFlowByPathResponse200ValueFailureModule:
 
         priority = d.pop("priority", UNSET)
 
+        continue_on_error = d.pop("continue_on_error", UNSET)
+
         _retry = d.pop("retry", UNSET)
         retry: Union[Unset, GetFlowByPathResponse200ValueFailureModuleRetry]
         if isinstance(_retry, Unset):
@@ -250,6 +257,7 @@ class GetFlowByPathResponse200ValueFailureModule:
             mock=mock,
             suspend=suspend,
             priority=priority,
+            continue_on_error=continue_on_error,
             retry=retry,
         )
 
