@@ -36,7 +36,6 @@ class GetFlowByPathWithDraftResponse200Draft:
         description (Union[Unset, str]):
         schema (Union[Unset, GetFlowByPathWithDraftResponse200DraftSchema]):
         workspace_id (Union[Unset, str]):
-        additional_properties (Union[Unset, bool]):
         starred (Union[Unset, bool]):
         draft_only (Union[Unset, bool]):
         tag (Union[Unset, str]):
@@ -44,6 +43,7 @@ class GetFlowByPathWithDraftResponse200Draft:
         priority (Union[Unset, int]):
         dedicated_worker (Union[Unset, bool]):
         timeout (Union[Unset, float]):
+        visible_to_runner_only (Union[Unset, bool]):
     """
 
     summary: str
@@ -56,7 +56,6 @@ class GetFlowByPathWithDraftResponse200Draft:
     description: Union[Unset, str] = UNSET
     schema: Union[Unset, "GetFlowByPathWithDraftResponse200DraftSchema"] = UNSET
     workspace_id: Union[Unset, str] = UNSET
-    additional_properties: Union[Unset, bool] = UNSET
     starred: Union[Unset, bool] = UNSET
     draft_only: Union[Unset, bool] = UNSET
     tag: Union[Unset, str] = UNSET
@@ -64,6 +63,7 @@ class GetFlowByPathWithDraftResponse200Draft:
     priority: Union[Unset, int] = UNSET
     dedicated_worker: Union[Unset, bool] = UNSET
     timeout: Union[Unset, float] = UNSET
+    visible_to_runner_only: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -83,7 +83,6 @@ class GetFlowByPathWithDraftResponse200Draft:
             schema = self.schema.to_dict()
 
         workspace_id = self.workspace_id
-        additional_properties = self.additional_properties
         starred = self.starred
         draft_only = self.draft_only
         tag = self.tag
@@ -91,6 +90,7 @@ class GetFlowByPathWithDraftResponse200Draft:
         priority = self.priority
         dedicated_worker = self.dedicated_worker
         timeout = self.timeout
+        visible_to_runner_only = self.visible_to_runner_only
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -111,8 +111,6 @@ class GetFlowByPathWithDraftResponse200Draft:
             field_dict["schema"] = schema
         if workspace_id is not UNSET:
             field_dict["workspace_id"] = workspace_id
-        if additional_properties is not UNSET:
-            field_dict["additionalProperties"] = additional_properties
         if starred is not UNSET:
             field_dict["starred"] = starred
         if draft_only is not UNSET:
@@ -127,6 +125,8 @@ class GetFlowByPathWithDraftResponse200Draft:
             field_dict["dedicated_worker"] = dedicated_worker
         if timeout is not UNSET:
             field_dict["timeout"] = timeout
+        if visible_to_runner_only is not UNSET:
+            field_dict["visible_to_runner_only"] = visible_to_runner_only
 
         return field_dict
 
@@ -168,8 +168,6 @@ class GetFlowByPathWithDraftResponse200Draft:
 
         workspace_id = d.pop("workspace_id", UNSET)
 
-        additional_properties = d.pop("additionalProperties", UNSET)
-
         starred = d.pop("starred", UNSET)
 
         draft_only = d.pop("draft_only", UNSET)
@@ -184,6 +182,8 @@ class GetFlowByPathWithDraftResponse200Draft:
 
         timeout = d.pop("timeout", UNSET)
 
+        visible_to_runner_only = d.pop("visible_to_runner_only", UNSET)
+
         get_flow_by_path_with_draft_response_200_draft = cls(
             summary=summary,
             value=value,
@@ -195,7 +195,6 @@ class GetFlowByPathWithDraftResponse200Draft:
             description=description,
             schema=schema,
             workspace_id=workspace_id,
-            additional_properties=additional_properties,
             starred=starred,
             draft_only=draft_only,
             tag=tag,
@@ -203,6 +202,7 @@ class GetFlowByPathWithDraftResponse200Draft:
             priority=priority,
             dedicated_worker=dedicated_worker,
             timeout=timeout,
+            visible_to_runner_only=visible_to_runner_only,
         )
 
         get_flow_by_path_with_draft_response_200_draft.additional_properties = d
