@@ -1,13 +1,14 @@
 from typing import Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
 from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="GetHubScriptByPathResponse200")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class GetHubScriptByPathResponse200:
     """
     Attributes:
@@ -23,7 +24,7 @@ class GetHubScriptByPathResponse200:
     lockfile: Union[Unset, str] = UNSET
     schema: Union[Unset, Any] = UNSET
     summary: Union[Unset, str] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         content = self.content
