@@ -19,6 +19,7 @@ class GetJobUpdatesResponse200:
         running (Union[Unset, bool]):
         completed (Union[Unset, bool]):
         new_logs (Union[Unset, str]):
+        log_offset (Union[Unset, int]):
         mem_peak (Union[Unset, int]):
         flow_status (Union[Unset, GetJobUpdatesResponse200FlowStatus]):
     """
@@ -26,6 +27,7 @@ class GetJobUpdatesResponse200:
     running: Union[Unset, bool] = UNSET
     completed: Union[Unset, bool] = UNSET
     new_logs: Union[Unset, str] = UNSET
+    log_offset: Union[Unset, int] = UNSET
     mem_peak: Union[Unset, int] = UNSET
     flow_status: Union[Unset, "GetJobUpdatesResponse200FlowStatus"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
@@ -34,6 +36,7 @@ class GetJobUpdatesResponse200:
         running = self.running
         completed = self.completed
         new_logs = self.new_logs
+        log_offset = self.log_offset
         mem_peak = self.mem_peak
         flow_status: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.flow_status, Unset):
@@ -48,6 +51,8 @@ class GetJobUpdatesResponse200:
             field_dict["completed"] = completed
         if new_logs is not UNSET:
             field_dict["new_logs"] = new_logs
+        if log_offset is not UNSET:
+            field_dict["log_offset"] = log_offset
         if mem_peak is not UNSET:
             field_dict["mem_peak"] = mem_peak
         if flow_status is not UNSET:
@@ -66,6 +71,8 @@ class GetJobUpdatesResponse200:
 
         new_logs = d.pop("new_logs", UNSET)
 
+        log_offset = d.pop("log_offset", UNSET)
+
         mem_peak = d.pop("mem_peak", UNSET)
 
         _flow_status = d.pop("flow_status", UNSET)
@@ -79,6 +86,7 @@ class GetJobUpdatesResponse200:
             running=running,
             completed=completed,
             new_logs=new_logs,
+            log_offset=log_offset,
             mem_peak=mem_peak,
             flow_status=flow_status,
         )
