@@ -13,17 +13,20 @@ class GetPremiumInfoResponse200:
     """
     Attributes:
         premium (bool):
+        automatic_billing (bool):
         usage (Union[Unset, float]):
         seats (Union[Unset, float]):
     """
 
     premium: bool
+    automatic_billing: bool
     usage: Union[Unset, float] = UNSET
     seats: Union[Unset, float] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         premium = self.premium
+        automatic_billing = self.automatic_billing
         usage = self.usage
         seats = self.seats
 
@@ -32,6 +35,7 @@ class GetPremiumInfoResponse200:
         field_dict.update(
             {
                 "premium": premium,
+                "automatic_billing": automatic_billing,
             }
         )
         if usage is not UNSET:
@@ -46,12 +50,15 @@ class GetPremiumInfoResponse200:
         d = src_dict.copy()
         premium = d.pop("premium")
 
+        automatic_billing = d.pop("automatic_billing")
+
         usage = d.pop("usage", UNSET)
 
         seats = d.pop("seats", UNSET)
 
         get_premium_info_response_200 = cls(
             premium=premium,
+            automatic_billing=automatic_billing,
             usage=usage,
             seats=seats,
         )
