@@ -10,6 +10,7 @@ from ..models.get_public_app_by_secret_response_200_execution_mode import GetPub
 if TYPE_CHECKING:
     from ..models.get_public_app_by_secret_response_200_extra_perms import GetPublicAppBySecretResponse200ExtraPerms
     from ..models.get_public_app_by_secret_response_200_policy import GetPublicAppBySecretResponse200Policy
+    from ..models.get_public_app_by_secret_response_200_value import GetPublicAppBySecretResponse200Value
 
 
 T = TypeVar("T", bound="GetPublicAppBySecretResponse200")
@@ -26,7 +27,7 @@ class GetPublicAppBySecretResponse200:
         versions (List[int]):
         created_by (str):
         created_at (datetime.datetime):
-        value (Any):
+        value (GetPublicAppBySecretResponse200Value):
         policy (GetPublicAppBySecretResponse200Policy):
         execution_mode (GetPublicAppBySecretResponse200ExecutionMode):
         extra_perms (GetPublicAppBySecretResponse200ExtraPerms):
@@ -39,7 +40,7 @@ class GetPublicAppBySecretResponse200:
     versions: List[int]
     created_by: str
     created_at: datetime.datetime
-    value: Any
+    value: "GetPublicAppBySecretResponse200Value"
     policy: "GetPublicAppBySecretResponse200Policy"
     execution_mode: GetPublicAppBySecretResponse200ExecutionMode
     extra_perms: "GetPublicAppBySecretResponse200ExtraPerms"
@@ -55,7 +56,8 @@ class GetPublicAppBySecretResponse200:
         created_by = self.created_by
         created_at = self.created_at.isoformat()
 
-        value = self.value
+        value = self.value.to_dict()
+
         policy = self.policy.to_dict()
 
         execution_mode = self.execution_mode.value
@@ -86,6 +88,7 @@ class GetPublicAppBySecretResponse200:
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.get_public_app_by_secret_response_200_extra_perms import GetPublicAppBySecretResponse200ExtraPerms
         from ..models.get_public_app_by_secret_response_200_policy import GetPublicAppBySecretResponse200Policy
+        from ..models.get_public_app_by_secret_response_200_value import GetPublicAppBySecretResponse200Value
 
         d = src_dict.copy()
         id = d.pop("id")
@@ -102,7 +105,7 @@ class GetPublicAppBySecretResponse200:
 
         created_at = isoparse(d.pop("created_at"))
 
-        value = d.pop("value")
+        value = GetPublicAppBySecretResponse200Value.from_dict(d.pop("value"))
 
         policy = GetPublicAppBySecretResponse200Policy.from_dict(d.pop("policy"))
 
