@@ -12,6 +12,7 @@ if TYPE_CHECKING:
     from ..models.get_schedule_response_200_extra_perms import GetScheduleResponse200ExtraPerms
     from ..models.get_schedule_response_200_on_failure_extra_args import GetScheduleResponse200OnFailureExtraArgs
     from ..models.get_schedule_response_200_on_recovery_extra_args import GetScheduleResponse200OnRecoveryExtraArgs
+    from ..models.get_schedule_response_200_retry import GetScheduleResponse200Retry
 
 
 T = TypeVar("T", bound="GetScheduleResponse200")
@@ -41,6 +42,10 @@ class GetScheduleResponse200:
         on_recovery_times (Union[Unset, float]):
         on_recovery_extra_args (Union[Unset, GetScheduleResponse200OnRecoveryExtraArgs]):
         ws_error_handler_muted (Union[Unset, bool]):
+        retry (Union[Unset, GetScheduleResponse200Retry]):
+        summary (Union[Unset, str]):
+        no_flow_overlap (Union[Unset, bool]):
+        tag (Union[Unset, str]):
     """
 
     path: str
@@ -63,6 +68,10 @@ class GetScheduleResponse200:
     on_recovery_times: Union[Unset, float] = UNSET
     on_recovery_extra_args: Union[Unset, "GetScheduleResponse200OnRecoveryExtraArgs"] = UNSET
     ws_error_handler_muted: Union[Unset, bool] = UNSET
+    retry: Union[Unset, "GetScheduleResponse200Retry"] = UNSET
+    summary: Union[Unset, str] = UNSET
+    no_flow_overlap: Union[Unset, bool] = UNSET
+    tag: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -97,6 +106,13 @@ class GetScheduleResponse200:
             on_recovery_extra_args = self.on_recovery_extra_args.to_dict()
 
         ws_error_handler_muted = self.ws_error_handler_muted
+        retry: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.retry, Unset):
+            retry = self.retry.to_dict()
+
+        summary = self.summary
+        no_flow_overlap = self.no_flow_overlap
+        tag = self.tag
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -134,6 +150,14 @@ class GetScheduleResponse200:
             field_dict["on_recovery_extra_args"] = on_recovery_extra_args
         if ws_error_handler_muted is not UNSET:
             field_dict["ws_error_handler_muted"] = ws_error_handler_muted
+        if retry is not UNSET:
+            field_dict["retry"] = retry
+        if summary is not UNSET:
+            field_dict["summary"] = summary
+        if no_flow_overlap is not UNSET:
+            field_dict["no_flow_overlap"] = no_flow_overlap
+        if tag is not UNSET:
+            field_dict["tag"] = tag
 
         return field_dict
 
@@ -143,6 +167,7 @@ class GetScheduleResponse200:
         from ..models.get_schedule_response_200_extra_perms import GetScheduleResponse200ExtraPerms
         from ..models.get_schedule_response_200_on_failure_extra_args import GetScheduleResponse200OnFailureExtraArgs
         from ..models.get_schedule_response_200_on_recovery_extra_args import GetScheduleResponse200OnRecoveryExtraArgs
+        from ..models.get_schedule_response_200_retry import GetScheduleResponse200Retry
 
         d = src_dict.copy()
         path = d.pop("path")
@@ -200,6 +225,19 @@ class GetScheduleResponse200:
 
         ws_error_handler_muted = d.pop("ws_error_handler_muted", UNSET)
 
+        _retry = d.pop("retry", UNSET)
+        retry: Union[Unset, GetScheduleResponse200Retry]
+        if isinstance(_retry, Unset):
+            retry = UNSET
+        else:
+            retry = GetScheduleResponse200Retry.from_dict(_retry)
+
+        summary = d.pop("summary", UNSET)
+
+        no_flow_overlap = d.pop("no_flow_overlap", UNSET)
+
+        tag = d.pop("tag", UNSET)
+
         get_schedule_response_200 = cls(
             path=path,
             edited_by=edited_by,
@@ -221,6 +259,10 @@ class GetScheduleResponse200:
             on_recovery_times=on_recovery_times,
             on_recovery_extra_args=on_recovery_extra_args,
             ws_error_handler_muted=ws_error_handler_muted,
+            retry=retry,
+            summary=summary,
+            no_flow_overlap=no_flow_overlap,
+            tag=tag,
         )
 
         get_schedule_response_200.additional_properties = d
