@@ -44,6 +44,9 @@ class GetScriptByPathWithDraftResponse200:
         delete_after_use (Union[Unset, bool]):
         deployment_message (Union[Unset, str]):
         concurrency_key (Union[Unset, str]):
+        visible_to_runner_only (Union[Unset, bool]):
+        no_main_func (Union[Unset, bool]):
+        codebase (Union[Unset, str]):
         draft (Union[Unset, GetScriptByPathWithDraftResponse200Draft]):
     """
 
@@ -72,6 +75,9 @@ class GetScriptByPathWithDraftResponse200:
     delete_after_use: Union[Unset, bool] = UNSET
     deployment_message: Union[Unset, str] = UNSET
     concurrency_key: Union[Unset, str] = UNSET
+    visible_to_runner_only: Union[Unset, bool] = UNSET
+    no_main_func: Union[Unset, bool] = UNSET
+    codebase: Union[Unset, str] = UNSET
     draft: Union[Unset, "GetScriptByPathWithDraftResponse200Draft"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
@@ -111,6 +117,9 @@ class GetScriptByPathWithDraftResponse200:
         delete_after_use = self.delete_after_use
         deployment_message = self.deployment_message
         concurrency_key = self.concurrency_key
+        visible_to_runner_only = self.visible_to_runner_only
+        no_main_func = self.no_main_func
+        codebase = self.codebase
         draft: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.draft, Unset):
             draft = self.draft.to_dict()
@@ -165,6 +174,12 @@ class GetScriptByPathWithDraftResponse200:
             field_dict["deployment_message"] = deployment_message
         if concurrency_key is not UNSET:
             field_dict["concurrency_key"] = concurrency_key
+        if visible_to_runner_only is not UNSET:
+            field_dict["visible_to_runner_only"] = visible_to_runner_only
+        if no_main_func is not UNSET:
+            field_dict["no_main_func"] = no_main_func
+        if codebase is not UNSET:
+            field_dict["codebase"] = codebase
         if draft is not UNSET:
             field_dict["draft"] = draft
 
@@ -236,6 +251,12 @@ class GetScriptByPathWithDraftResponse200:
 
         concurrency_key = d.pop("concurrency_key", UNSET)
 
+        visible_to_runner_only = d.pop("visible_to_runner_only", UNSET)
+
+        no_main_func = d.pop("no_main_func", UNSET)
+
+        codebase = d.pop("codebase", UNSET)
+
         _draft = d.pop("draft", UNSET)
         draft: Union[Unset, GetScriptByPathWithDraftResponse200Draft]
         if isinstance(_draft, Unset):
@@ -269,6 +290,9 @@ class GetScriptByPathWithDraftResponse200:
             delete_after_use=delete_after_use,
             deployment_message=deployment_message,
             concurrency_key=concurrency_key,
+            visible_to_runner_only=visible_to_runner_only,
+            no_main_func=no_main_func,
+            codebase=codebase,
             draft=draft,
         )
 
