@@ -19,6 +19,7 @@ class GlobalUserInfo:
         verified (bool):
         name (Union[Unset, str]):
         company (Union[Unset, str]):
+        username (Union[Unset, str]):
     """
 
     email: str
@@ -27,6 +28,7 @@ class GlobalUserInfo:
     verified: bool
     name: Union[Unset, str] = UNSET
     company: Union[Unset, str] = UNSET
+    username: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -37,6 +39,7 @@ class GlobalUserInfo:
         verified = self.verified
         name = self.name
         company = self.company
+        username = self.username
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -52,6 +55,8 @@ class GlobalUserInfo:
             field_dict["name"] = name
         if company is not UNSET:
             field_dict["company"] = company
+        if username is not UNSET:
+            field_dict["username"] = username
 
         return field_dict
 
@@ -70,6 +75,8 @@ class GlobalUserInfo:
 
         company = d.pop("company", UNSET)
 
+        username = d.pop("username", UNSET)
+
         global_user_info = cls(
             email=email,
             login_type=login_type,
@@ -77,6 +84,7 @@ class GlobalUserInfo:
             verified=verified,
             name=name,
             company=company,
+            username=username,
         )
 
         global_user_info.additional_properties = d
