@@ -25,6 +25,7 @@ class ListCompletedJobsResponse200ItemRawFlow:
         failure_module (Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModule]):
         same_worker (Union[Unset, bool]):
         concurrent_limit (Union[Unset, float]):
+        concurrency_key (Union[Unset, str]):
         concurrency_time_window_s (Union[Unset, float]):
         skip_expr (Union[Unset, str]):
         cache_ttl (Union[Unset, float]):
@@ -36,6 +37,7 @@ class ListCompletedJobsResponse200ItemRawFlow:
     failure_module: Union[Unset, "ListCompletedJobsResponse200ItemRawFlowFailureModule"] = UNSET
     same_worker: Union[Unset, bool] = UNSET
     concurrent_limit: Union[Unset, float] = UNSET
+    concurrency_key: Union[Unset, str] = UNSET
     concurrency_time_window_s: Union[Unset, float] = UNSET
     skip_expr: Union[Unset, str] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
@@ -56,6 +58,7 @@ class ListCompletedJobsResponse200ItemRawFlow:
 
         same_worker = self.same_worker
         concurrent_limit = self.concurrent_limit
+        concurrency_key = self.concurrency_key
         concurrency_time_window_s = self.concurrency_time_window_s
         skip_expr = self.skip_expr
         cache_ttl = self.cache_ttl
@@ -75,6 +78,8 @@ class ListCompletedJobsResponse200ItemRawFlow:
             field_dict["same_worker"] = same_worker
         if concurrent_limit is not UNSET:
             field_dict["concurrent_limit"] = concurrent_limit
+        if concurrency_key is not UNSET:
+            field_dict["concurrency_key"] = concurrency_key
         if concurrency_time_window_s is not UNSET:
             field_dict["concurrency_time_window_s"] = concurrency_time_window_s
         if skip_expr is not UNSET:
@@ -116,6 +121,8 @@ class ListCompletedJobsResponse200ItemRawFlow:
 
         concurrent_limit = d.pop("concurrent_limit", UNSET)
 
+        concurrency_key = d.pop("concurrency_key", UNSET)
+
         concurrency_time_window_s = d.pop("concurrency_time_window_s", UNSET)
 
         skip_expr = d.pop("skip_expr", UNSET)
@@ -131,6 +138,7 @@ class ListCompletedJobsResponse200ItemRawFlow:
             failure_module=failure_module,
             same_worker=same_worker,
             concurrent_limit=concurrent_limit,
+            concurrency_key=concurrency_key,
             concurrency_time_window_s=concurrency_time_window_s,
             skip_expr=skip_expr,
             cache_ttl=cache_ttl,
