@@ -32,6 +32,7 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModuleSuspend:
             (Union['ListCompletedJobsResponse200ItemRawFlowFailureModuleSuspendUserGroupsRequiredType0',
             'ListCompletedJobsResponse200ItemRawFlowFailureModuleSuspendUserGroupsRequiredType1', Unset]):
         self_approval_disabled (Union[Unset, bool]):
+        hide_cancel (Union[Unset, bool]):
     """
 
     required_events: Union[Unset, int] = UNSET
@@ -44,6 +45,7 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModuleSuspend:
         Unset,
     ] = UNSET
     self_approval_disabled: Union[Unset, bool] = UNSET
+    hide_cancel: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -76,6 +78,7 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModuleSuspend:
                 user_groups_required = self.user_groups_required.to_dict()
 
         self_approval_disabled = self.self_approval_disabled
+        hide_cancel = self.hide_cancel
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -92,6 +95,8 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModuleSuspend:
             field_dict["user_groups_required"] = user_groups_required
         if self_approval_disabled is not UNSET:
             field_dict["self_approval_disabled"] = self_approval_disabled
+        if hide_cancel is not UNSET:
+            field_dict["hide_cancel"] = hide_cancel
 
         return field_dict
 
@@ -170,6 +175,8 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModuleSuspend:
 
         self_approval_disabled = d.pop("self_approval_disabled", UNSET)
 
+        hide_cancel = d.pop("hide_cancel", UNSET)
+
         list_completed_jobs_response_200_item_raw_flow_failure_module_suspend = cls(
             required_events=required_events,
             timeout=timeout,
@@ -177,6 +184,7 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModuleSuspend:
             user_auth_required=user_auth_required,
             user_groups_required=user_groups_required,
             self_approval_disabled=self_approval_disabled,
+            hide_cancel=hide_cancel,
         )
 
         list_completed_jobs_response_200_item_raw_flow_failure_module_suspend.additional_properties = d
