@@ -25,12 +25,14 @@ class ListQueueResponse200ItemFlowStatus:
         step (int):
         modules (List['ListQueueResponse200ItemFlowStatusModulesItem']):
         failure_module (ListQueueResponse200ItemFlowStatusFailureModule):
+        user_states (Union[Unset, Any]):
         retry (Union[Unset, ListQueueResponse200ItemFlowStatusRetry]):
     """
 
     step: int
     modules: List["ListQueueResponse200ItemFlowStatusModulesItem"]
     failure_module: "ListQueueResponse200ItemFlowStatusFailureModule"
+    user_states: Union[Unset, Any] = UNSET
     retry: Union[Unset, "ListQueueResponse200ItemFlowStatusRetry"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
@@ -44,6 +46,7 @@ class ListQueueResponse200ItemFlowStatus:
 
         failure_module = self.failure_module.to_dict()
 
+        user_states = self.user_states
         retry: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.retry, Unset):
             retry = self.retry.to_dict()
@@ -57,6 +60,8 @@ class ListQueueResponse200ItemFlowStatus:
                 "failure_module": failure_module,
             }
         )
+        if user_states is not UNSET:
+            field_dict["user_states"] = user_states
         if retry is not UNSET:
             field_dict["retry"] = retry
 
@@ -84,6 +89,8 @@ class ListQueueResponse200ItemFlowStatus:
 
         failure_module = ListQueueResponse200ItemFlowStatusFailureModule.from_dict(d.pop("failure_module"))
 
+        user_states = d.pop("user_states", UNSET)
+
         _retry = d.pop("retry", UNSET)
         retry: Union[Unset, ListQueueResponse200ItemFlowStatusRetry]
         if isinstance(_retry, Unset):
@@ -95,6 +102,7 @@ class ListQueueResponse200ItemFlowStatus:
             step=step,
             modules=modules,
             failure_module=failure_module,
+            user_states=user_states,
             retry=retry,
         )
 
