@@ -23,6 +23,7 @@ class ListQueueResponse200ItemRawFlow:
         failure_module (Union[Unset, ListQueueResponse200ItemRawFlowFailureModule]):
         same_worker (Union[Unset, bool]):
         concurrent_limit (Union[Unset, float]):
+        concurrency_key (Union[Unset, str]):
         concurrency_time_window_s (Union[Unset, float]):
         skip_expr (Union[Unset, str]):
         cache_ttl (Union[Unset, float]):
@@ -34,6 +35,7 @@ class ListQueueResponse200ItemRawFlow:
     failure_module: Union[Unset, "ListQueueResponse200ItemRawFlowFailureModule"] = UNSET
     same_worker: Union[Unset, bool] = UNSET
     concurrent_limit: Union[Unset, float] = UNSET
+    concurrency_key: Union[Unset, str] = UNSET
     concurrency_time_window_s: Union[Unset, float] = UNSET
     skip_expr: Union[Unset, str] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
@@ -54,6 +56,7 @@ class ListQueueResponse200ItemRawFlow:
 
         same_worker = self.same_worker
         concurrent_limit = self.concurrent_limit
+        concurrency_key = self.concurrency_key
         concurrency_time_window_s = self.concurrency_time_window_s
         skip_expr = self.skip_expr
         cache_ttl = self.cache_ttl
@@ -73,6 +76,8 @@ class ListQueueResponse200ItemRawFlow:
             field_dict["same_worker"] = same_worker
         if concurrent_limit is not UNSET:
             field_dict["concurrent_limit"] = concurrent_limit
+        if concurrency_key is not UNSET:
+            field_dict["concurrency_key"] = concurrency_key
         if concurrency_time_window_s is not UNSET:
             field_dict["concurrency_time_window_s"] = concurrency_time_window_s
         if skip_expr is not UNSET:
@@ -114,6 +119,8 @@ class ListQueueResponse200ItemRawFlow:
 
         concurrent_limit = d.pop("concurrent_limit", UNSET)
 
+        concurrency_key = d.pop("concurrency_key", UNSET)
+
         concurrency_time_window_s = d.pop("concurrency_time_window_s", UNSET)
 
         skip_expr = d.pop("skip_expr", UNSET)
@@ -129,6 +136,7 @@ class ListQueueResponse200ItemRawFlow:
             failure_module=failure_module,
             same_worker=same_worker,
             concurrent_limit=concurrent_limit,
+            concurrency_key=concurrency_key,
             concurrency_time_window_s=concurrency_time_window_s,
             skip_expr=skip_expr,
             cache_ttl=cache_ttl,
