@@ -1,17 +1,21 @@
 import datetime
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 from dateutil.parser import isoparse
 
 from ..models.listable_app_execution_mode import ListableAppExecutionMode
-from ..models.listable_app_extra_perms import ListableAppExtraPerms
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.listable_app_extra_perms import ListableAppExtraPerms
+
+
 T = TypeVar("T", bound="ListableApp")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class ListableApp:
     """
     Attributes:
@@ -31,11 +35,11 @@ class ListableApp:
     path: str
     summary: str
     version: int
-    extra_perms: ListableAppExtraPerms
+    extra_perms: "ListableAppExtraPerms"
     edited_at: datetime.datetime
     execution_mode: ListableAppExecutionMode
     starred: Union[Unset, bool] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         id = self.id
@@ -72,6 +76,8 @@ class ListableApp:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.listable_app_extra_perms import ListableAppExtraPerms
+
         d = src_dict.copy()
         id = d.pop("id")
 
