@@ -42,6 +42,9 @@ class NewScript:
         delete_after_use (Union[Unset, bool]):
         deployment_message (Union[Unset, str]):
         concurrency_key (Union[Unset, str]):
+        visible_to_runner_only (Union[Unset, bool]):
+        no_main_func (Union[Unset, bool]):
+        codebase (Union[Unset, str]):
     """
 
     path: str
@@ -68,6 +71,9 @@ class NewScript:
     delete_after_use: Union[Unset, bool] = UNSET
     deployment_message: Union[Unset, str] = UNSET
     concurrency_key: Union[Unset, str] = UNSET
+    visible_to_runner_only: Union[Unset, bool] = UNSET
+    no_main_func: Union[Unset, bool] = UNSET
+    codebase: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -105,6 +111,9 @@ class NewScript:
         delete_after_use = self.delete_after_use
         deployment_message = self.deployment_message
         concurrency_key = self.concurrency_key
+        visible_to_runner_only = self.visible_to_runner_only
+        no_main_func = self.no_main_func
+        codebase = self.codebase
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -155,6 +164,12 @@ class NewScript:
             field_dict["deployment_message"] = deployment_message
         if concurrency_key is not UNSET:
             field_dict["concurrency_key"] = concurrency_key
+        if visible_to_runner_only is not UNSET:
+            field_dict["visible_to_runner_only"] = visible_to_runner_only
+        if no_main_func is not UNSET:
+            field_dict["no_main_func"] = no_main_func
+        if codebase is not UNSET:
+            field_dict["codebase"] = codebase
 
         return field_dict
 
@@ -221,6 +236,12 @@ class NewScript:
 
         concurrency_key = d.pop("concurrency_key", UNSET)
 
+        visible_to_runner_only = d.pop("visible_to_runner_only", UNSET)
+
+        no_main_func = d.pop("no_main_func", UNSET)
+
+        codebase = d.pop("codebase", UNSET)
+
         new_script = cls(
             path=path,
             summary=summary,
@@ -246,6 +267,9 @@ class NewScript:
             delete_after_use=delete_after_use,
             deployment_message=deployment_message,
             concurrency_key=concurrency_key,
+            visible_to_runner_only=visible_to_runner_only,
+            no_main_func=no_main_func,
+            codebase=codebase,
         )
 
         new_script.additional_properties = d
