@@ -27,6 +27,7 @@ class OpenFlowWPath:
         priority (Union[Unset, int]):
         dedicated_worker (Union[Unset, bool]):
         timeout (Union[Unset, float]):
+        visible_to_runner_only (Union[Unset, bool]):
     """
 
     summary: str
@@ -39,6 +40,7 @@ class OpenFlowWPath:
     priority: Union[Unset, int] = UNSET
     dedicated_worker: Union[Unset, bool] = UNSET
     timeout: Union[Unset, float] = UNSET
+    visible_to_runner_only: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -56,6 +58,7 @@ class OpenFlowWPath:
         priority = self.priority
         dedicated_worker = self.dedicated_worker
         timeout = self.timeout
+        visible_to_runner_only = self.visible_to_runner_only
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -80,6 +83,8 @@ class OpenFlowWPath:
             field_dict["dedicated_worker"] = dedicated_worker
         if timeout is not UNSET:
             field_dict["timeout"] = timeout
+        if visible_to_runner_only is not UNSET:
+            field_dict["visible_to_runner_only"] = visible_to_runner_only
 
         return field_dict
 
@@ -114,6 +119,8 @@ class OpenFlowWPath:
 
         timeout = d.pop("timeout", UNSET)
 
+        visible_to_runner_only = d.pop("visible_to_runner_only", UNSET)
+
         open_flow_w_path = cls(
             summary=summary,
             value=value,
@@ -125,6 +132,7 @@ class OpenFlowWPath:
             priority=priority,
             dedicated_worker=dedicated_worker,
             timeout=timeout,
+            visible_to_runner_only=visible_to_runner_only,
         )
 
         open_flow_w_path.additional_properties = d
