@@ -21,12 +21,14 @@ class QueuedJobFlowStatus:
         step (int):
         modules (List['QueuedJobFlowStatusModulesItem']):
         failure_module (QueuedJobFlowStatusFailureModule):
+        user_states (Union[Unset, Any]):
         retry (Union[Unset, QueuedJobFlowStatusRetry]):
     """
 
     step: int
     modules: List["QueuedJobFlowStatusModulesItem"]
     failure_module: "QueuedJobFlowStatusFailureModule"
+    user_states: Union[Unset, Any] = UNSET
     retry: Union[Unset, "QueuedJobFlowStatusRetry"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
@@ -40,6 +42,7 @@ class QueuedJobFlowStatus:
 
         failure_module = self.failure_module.to_dict()
 
+        user_states = self.user_states
         retry: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.retry, Unset):
             retry = self.retry.to_dict()
@@ -53,6 +56,8 @@ class QueuedJobFlowStatus:
                 "failure_module": failure_module,
             }
         )
+        if user_states is not UNSET:
+            field_dict["user_states"] = user_states
         if retry is not UNSET:
             field_dict["retry"] = retry
 
@@ -76,6 +81,8 @@ class QueuedJobFlowStatus:
 
         failure_module = QueuedJobFlowStatusFailureModule.from_dict(d.pop("failure_module"))
 
+        user_states = d.pop("user_states", UNSET)
+
         _retry = d.pop("retry", UNSET)
         retry: Union[Unset, QueuedJobFlowStatusRetry]
         if isinstance(_retry, Unset):
@@ -87,6 +94,7 @@ class QueuedJobFlowStatus:
             step=step,
             modules=modules,
             failure_module=failure_module,
+            user_states=user_states,
             retry=retry,
         )
 
