@@ -13,6 +13,7 @@ if TYPE_CHECKING:
     from ..models.schedule_w_jobs_jobs_item import ScheduleWJobsJobsItem
     from ..models.schedule_w_jobs_on_failure_extra_args import ScheduleWJobsOnFailureExtraArgs
     from ..models.schedule_w_jobs_on_recovery_extra_args import ScheduleWJobsOnRecoveryExtraArgs
+    from ..models.schedule_w_jobs_retry import ScheduleWJobsRetry
 
 
 T = TypeVar("T", bound="ScheduleWJobs")
@@ -42,6 +43,10 @@ class ScheduleWJobs:
         on_recovery_times (Union[Unset, float]):
         on_recovery_extra_args (Union[Unset, ScheduleWJobsOnRecoveryExtraArgs]):
         ws_error_handler_muted (Union[Unset, bool]):
+        retry (Union[Unset, ScheduleWJobsRetry]):
+        summary (Union[Unset, str]):
+        no_flow_overlap (Union[Unset, bool]):
+        tag (Union[Unset, str]):
         jobs (Union[Unset, List['ScheduleWJobsJobsItem']]):
     """
 
@@ -65,6 +70,10 @@ class ScheduleWJobs:
     on_recovery_times: Union[Unset, float] = UNSET
     on_recovery_extra_args: Union[Unset, "ScheduleWJobsOnRecoveryExtraArgs"] = UNSET
     ws_error_handler_muted: Union[Unset, bool] = UNSET
+    retry: Union[Unset, "ScheduleWJobsRetry"] = UNSET
+    summary: Union[Unset, str] = UNSET
+    no_flow_overlap: Union[Unset, bool] = UNSET
+    tag: Union[Unset, str] = UNSET
     jobs: Union[Unset, List["ScheduleWJobsJobsItem"]] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
@@ -100,6 +109,13 @@ class ScheduleWJobs:
             on_recovery_extra_args = self.on_recovery_extra_args.to_dict()
 
         ws_error_handler_muted = self.ws_error_handler_muted
+        retry: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.retry, Unset):
+            retry = self.retry.to_dict()
+
+        summary = self.summary
+        no_flow_overlap = self.no_flow_overlap
+        tag = self.tag
         jobs: Union[Unset, List[Dict[str, Any]]] = UNSET
         if not isinstance(self.jobs, Unset):
             jobs = []
@@ -144,6 +160,14 @@ class ScheduleWJobs:
             field_dict["on_recovery_extra_args"] = on_recovery_extra_args
         if ws_error_handler_muted is not UNSET:
             field_dict["ws_error_handler_muted"] = ws_error_handler_muted
+        if retry is not UNSET:
+            field_dict["retry"] = retry
+        if summary is not UNSET:
+            field_dict["summary"] = summary
+        if no_flow_overlap is not UNSET:
+            field_dict["no_flow_overlap"] = no_flow_overlap
+        if tag is not UNSET:
+            field_dict["tag"] = tag
         if jobs is not UNSET:
             field_dict["jobs"] = jobs
 
@@ -156,6 +180,7 @@ class ScheduleWJobs:
         from ..models.schedule_w_jobs_jobs_item import ScheduleWJobsJobsItem
         from ..models.schedule_w_jobs_on_failure_extra_args import ScheduleWJobsOnFailureExtraArgs
         from ..models.schedule_w_jobs_on_recovery_extra_args import ScheduleWJobsOnRecoveryExtraArgs
+        from ..models.schedule_w_jobs_retry import ScheduleWJobsRetry
 
         d = src_dict.copy()
         path = d.pop("path")
@@ -213,6 +238,19 @@ class ScheduleWJobs:
 
         ws_error_handler_muted = d.pop("ws_error_handler_muted", UNSET)
 
+        _retry = d.pop("retry", UNSET)
+        retry: Union[Unset, ScheduleWJobsRetry]
+        if isinstance(_retry, Unset):
+            retry = UNSET
+        else:
+            retry = ScheduleWJobsRetry.from_dict(_retry)
+
+        summary = d.pop("summary", UNSET)
+
+        no_flow_overlap = d.pop("no_flow_overlap", UNSET)
+
+        tag = d.pop("tag", UNSET)
+
         jobs = []
         _jobs = d.pop("jobs", UNSET)
         for jobs_item_data in _jobs or []:
@@ -241,6 +279,10 @@ class ScheduleWJobs:
             on_recovery_times=on_recovery_times,
             on_recovery_extra_args=on_recovery_extra_args,
             ws_error_handler_muted=ws_error_handler_muted,
+            retry=retry,
+            summary=summary,
+            no_flow_overlap=no_flow_overlap,
+            tag=tag,
             jobs=jobs,
         )
 
