@@ -35,6 +35,7 @@ class Script:
         language (ScriptLanguage):
         kind (ScriptKind):
         starred (bool):
+        no_main_func (bool):
         workspace_id (Union[Unset, str]):
         parent_hashes (Union[Unset, List[str]]): The first element is the direct parent of the script, the second is the
             parent of the first, etc
@@ -54,6 +55,8 @@ class Script:
         restart_unless_cancelled (Union[Unset, bool]):
         timeout (Union[Unset, int]):
         delete_after_use (Union[Unset, bool]):
+        visible_to_runner_only (Union[Unset, bool]):
+        codebase (Union[Unset, str]):
     """
 
     hash_: str
@@ -70,6 +73,7 @@ class Script:
     language: ScriptLanguage
     kind: ScriptKind
     starred: bool
+    no_main_func: bool
     workspace_id: Union[Unset, str] = UNSET
     parent_hashes: Union[Unset, List[str]] = UNSET
     schema: Union[Unset, "ScriptSchema"] = UNSET
@@ -88,6 +92,8 @@ class Script:
     restart_unless_cancelled: Union[Unset, bool] = UNSET
     timeout: Union[Unset, int] = UNSET
     delete_after_use: Union[Unset, bool] = UNSET
+    visible_to_runner_only: Union[Unset, bool] = UNSET
+    codebase: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -109,6 +115,7 @@ class Script:
         kind = self.kind.value
 
         starred = self.starred
+        no_main_func = self.no_main_func
         workspace_id = self.workspace_id
         parent_hashes: Union[Unset, List[str]] = UNSET
         if not isinstance(self.parent_hashes, Unset):
@@ -136,6 +143,8 @@ class Script:
         restart_unless_cancelled = self.restart_unless_cancelled
         timeout = self.timeout
         delete_after_use = self.delete_after_use
+        visible_to_runner_only = self.visible_to_runner_only
+        codebase = self.codebase
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -155,6 +164,7 @@ class Script:
                 "language": language,
                 "kind": kind,
                 "starred": starred,
+                "no_main_func": no_main_func,
             }
         )
         if workspace_id is not UNSET:
@@ -193,6 +203,10 @@ class Script:
             field_dict["timeout"] = timeout
         if delete_after_use is not UNSET:
             field_dict["delete_after_use"] = delete_after_use
+        if visible_to_runner_only is not UNSET:
+            field_dict["visible_to_runner_only"] = visible_to_runner_only
+        if codebase is not UNSET:
+            field_dict["codebase"] = codebase
 
         return field_dict
 
@@ -230,6 +244,8 @@ class Script:
 
         starred = d.pop("starred")
 
+        no_main_func = d.pop("no_main_func")
+
         workspace_id = d.pop("workspace_id", UNSET)
 
         parent_hashes = cast(List[str], d.pop("parent_hashes", UNSET))
@@ -271,6 +287,10 @@ class Script:
 
         delete_after_use = d.pop("delete_after_use", UNSET)
 
+        visible_to_runner_only = d.pop("visible_to_runner_only", UNSET)
+
+        codebase = d.pop("codebase", UNSET)
+
         script = cls(
             hash_=hash_,
             path=path,
@@ -286,6 +306,7 @@ class Script:
             language=language,
             kind=kind,
             starred=starred,
+            no_main_func=no_main_func,
             workspace_id=workspace_id,
             parent_hashes=parent_hashes,
             schema=schema,
@@ -304,6 +325,8 @@ class Script:
             restart_unless_cancelled=restart_unless_cancelled,
             timeout=timeout,
             delete_after_use=delete_after_use,
+            visible_to_runner_only=visible_to_runner_only,
+            codebase=codebase,
         )
 
         script.additional_properties = d
