@@ -9,6 +9,7 @@ if TYPE_CHECKING:
     from ..models.update_schedule_json_body_args import UpdateScheduleJsonBodyArgs
     from ..models.update_schedule_json_body_on_failure_extra_args import UpdateScheduleJsonBodyOnFailureExtraArgs
     from ..models.update_schedule_json_body_on_recovery_extra_args import UpdateScheduleJsonBodyOnRecoveryExtraArgs
+    from ..models.update_schedule_json_body_retry import UpdateScheduleJsonBodyRetry
 
 
 T = TypeVar("T", bound="UpdateScheduleJsonBody")
@@ -29,6 +30,10 @@ class UpdateScheduleJsonBody:
         on_recovery_times (Union[Unset, float]):
         on_recovery_extra_args (Union[Unset, UpdateScheduleJsonBodyOnRecoveryExtraArgs]):
         ws_error_handler_muted (Union[Unset, bool]):
+        retry (Union[Unset, UpdateScheduleJsonBodyRetry]):
+        no_flow_overlap (Union[Unset, bool]):
+        summary (Union[Unset, str]):
+        tag (Union[Unset, str]):
     """
 
     schedule: str
@@ -42,6 +47,10 @@ class UpdateScheduleJsonBody:
     on_recovery_times: Union[Unset, float] = UNSET
     on_recovery_extra_args: Union[Unset, "UpdateScheduleJsonBodyOnRecoveryExtraArgs"] = UNSET
     ws_error_handler_muted: Union[Unset, bool] = UNSET
+    retry: Union[Unset, "UpdateScheduleJsonBodyRetry"] = UNSET
+    no_flow_overlap: Union[Unset, bool] = UNSET
+    summary: Union[Unset, str] = UNSET
+    tag: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -63,6 +72,13 @@ class UpdateScheduleJsonBody:
             on_recovery_extra_args = self.on_recovery_extra_args.to_dict()
 
         ws_error_handler_muted = self.ws_error_handler_muted
+        retry: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.retry, Unset):
+            retry = self.retry.to_dict()
+
+        no_flow_overlap = self.no_flow_overlap
+        summary = self.summary
+        tag = self.tag
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -89,6 +105,14 @@ class UpdateScheduleJsonBody:
             field_dict["on_recovery_extra_args"] = on_recovery_extra_args
         if ws_error_handler_muted is not UNSET:
             field_dict["ws_error_handler_muted"] = ws_error_handler_muted
+        if retry is not UNSET:
+            field_dict["retry"] = retry
+        if no_flow_overlap is not UNSET:
+            field_dict["no_flow_overlap"] = no_flow_overlap
+        if summary is not UNSET:
+            field_dict["summary"] = summary
+        if tag is not UNSET:
+            field_dict["tag"] = tag
 
         return field_dict
 
@@ -97,6 +121,7 @@ class UpdateScheduleJsonBody:
         from ..models.update_schedule_json_body_args import UpdateScheduleJsonBodyArgs
         from ..models.update_schedule_json_body_on_failure_extra_args import UpdateScheduleJsonBodyOnFailureExtraArgs
         from ..models.update_schedule_json_body_on_recovery_extra_args import UpdateScheduleJsonBodyOnRecoveryExtraArgs
+        from ..models.update_schedule_json_body_retry import UpdateScheduleJsonBodyRetry
 
         d = src_dict.copy()
         schedule = d.pop("schedule")
@@ -131,6 +156,19 @@ class UpdateScheduleJsonBody:
 
         ws_error_handler_muted = d.pop("ws_error_handler_muted", UNSET)
 
+        _retry = d.pop("retry", UNSET)
+        retry: Union[Unset, UpdateScheduleJsonBodyRetry]
+        if isinstance(_retry, Unset):
+            retry = UNSET
+        else:
+            retry = UpdateScheduleJsonBodyRetry.from_dict(_retry)
+
+        no_flow_overlap = d.pop("no_flow_overlap", UNSET)
+
+        summary = d.pop("summary", UNSET)
+
+        tag = d.pop("tag", UNSET)
+
         update_schedule_json_body = cls(
             schedule=schedule,
             timezone=timezone,
@@ -143,6 +181,10 @@ class UpdateScheduleJsonBody:
             on_recovery_times=on_recovery_times,
             on_recovery_extra_args=on_recovery_extra_args,
             ws_error_handler_muted=ws_error_handler_muted,
+            retry=retry,
+            no_flow_overlap=no_flow_overlap,
+            summary=summary,
+            tag=tag,
         )
 
         update_schedule_json_body.additional_properties = d
