@@ -1,5 +1,5 @@
 import datetime
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast
+from typing import Any, Dict, List, Type, TypeVar, Union, cast
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
@@ -7,10 +7,6 @@ from dateutil.parser import isoparse
 
 from ..types import UNSET, Unset
 
-if TYPE_CHECKING:
-    from ..models.user_usage import UserUsage
-
-
 T = TypeVar("T", bound="User")
 
 
@@ -28,7 +24,6 @@ class User:
         folders (List[str]):
         folders_owners (List[str]):
         groups (Union[Unset, List[str]]):
-        usage (Union[Unset, UserUsage]):
     """
 
     email: str
@@ -41,7 +36,6 @@ class User:
     folders: List[str]
     folders_owners: List[str]
     groups: Union[Unset, List[str]] = UNSET
-    usage: Union[Unset, "UserUsage"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -61,10 +55,6 @@ class User:
         if not isinstance(self.groups, Unset):
             groups = self.groups
 
-        usage: Union[Unset, Dict[str, Any]] = UNSET
-        if not isinstance(self.usage, Unset):
-            usage = self.usage.to_dict()
-
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -82,15 +72,11 @@ class User:
         )
         if groups is not UNSET:
             field_dict["groups"] = groups
-        if usage is not UNSET:
-            field_dict["usage"] = usage
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
-        from ..models.user_usage import UserUsage
-
         d = src_dict.copy()
         email = d.pop("email")
 
@@ -112,13 +98,6 @@ class User:
 
         groups = cast(List[str], d.pop("groups", UNSET))
 
-        _usage = d.pop("usage", UNSET)
-        usage: Union[Unset, UserUsage]
-        if isinstance(_usage, Unset):
-            usage = UNSET
-        else:
-            usage = UserUsage.from_dict(_usage)
-
         user = cls(
             email=email,
             username=username,
@@ -130,7 +109,6 @@ class User:
             folders=folders,
             folders_owners=folders_owners,
             groups=groups,
-            usage=usage,
         )
 
         user.additional_properties = d
