@@ -23,6 +23,9 @@ class WorkerPing:
         wm_version (str):
         last_ping (Union[Unset, float]):
         custom_tags (Union[Unset, List[str]]):
+        current_job_id (Union[Unset, str]):
+        current_job_workspace_id (Union[Unset, str]):
+        occupancy_rate (Union[Unset, float]):
     """
 
     worker: str
@@ -34,6 +37,9 @@ class WorkerPing:
     wm_version: str
     last_ping: Union[Unset, float] = UNSET
     custom_tags: Union[Unset, List[str]] = UNSET
+    current_job_id: Union[Unset, str] = UNSET
+    current_job_workspace_id: Union[Unset, str] = UNSET
+    occupancy_rate: Union[Unset, float] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -50,6 +56,10 @@ class WorkerPing:
         if not isinstance(self.custom_tags, Unset):
             custom_tags = self.custom_tags
 
+        current_job_id = self.current_job_id
+        current_job_workspace_id = self.current_job_workspace_id
+        occupancy_rate = self.occupancy_rate
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -67,6 +77,12 @@ class WorkerPing:
             field_dict["last_ping"] = last_ping
         if custom_tags is not UNSET:
             field_dict["custom_tags"] = custom_tags
+        if current_job_id is not UNSET:
+            field_dict["current_job_id"] = current_job_id
+        if current_job_workspace_id is not UNSET:
+            field_dict["current_job_workspace_id"] = current_job_workspace_id
+        if occupancy_rate is not UNSET:
+            field_dict["occupancy_rate"] = occupancy_rate
 
         return field_dict
 
@@ -91,6 +107,12 @@ class WorkerPing:
 
         custom_tags = cast(List[str], d.pop("custom_tags", UNSET))
 
+        current_job_id = d.pop("current_job_id", UNSET)
+
+        current_job_workspace_id = d.pop("current_job_workspace_id", UNSET)
+
+        occupancy_rate = d.pop("occupancy_rate", UNSET)
+
         worker_ping = cls(
             worker=worker,
             worker_instance=worker_instance,
@@ -101,6 +123,9 @@ class WorkerPing:
             wm_version=wm_version,
             last_ping=last_ping,
             custom_tags=custom_tags,
+            current_job_id=current_job_id,
+            current_job_workspace_id=current_job_workspace_id,
+            occupancy_rate=occupancy_rate,
         )
 
         worker_ping.additional_properties = d
